tic;    
[VOI, STATES, ALGEBRAIC, CONSTANTS] = mainFunction();
toc;

function [VOI, STATES, ALGEBRAIC, CONSTANTS] = mainFunction()
    % This is the "main function".  In Matlab, things work best if you rename this function to match the filename.
   [VOI, STATES, ALGEBRAIC, CONSTANTS] = solveModel();
end

function [algebraicVariableCount] = getAlgebraicVariableCount()
    % Used later when setting a global variable with the number of algebraic variables.
    % Note: This is not the "main method".
    algebraicVariableCount =231;
end
% There are a total of 57 entries in each of the rate and state variable arrays.
% There are a total of 181 entries in the constant variable array.
%

function [VOI, STATES, ALGEBRAIC, CONSTANTS] = solveModel()
    [LEGEND_STATES, LEGEND_ALGEBRAIC, LEGEND_VOI, LEGEND_CONSTANTS] = createLegends();
    % Create ALGEBRAIC of correct size
    global algebraicVariableCount;  algebraicVariableCount = getAlgebraicVariableCount();
    % Initialise constants and state variables
    [INIT_STATES, CONSTANTS] = initConsts;

    % Set timespan to solve over
    tspan = [0, 1e-1];

    % Set numerical accuracy options for ODE solver
    options = odeset('RelTol', 1e-06, 'AbsTol', 1e-06, 'MaxStep', 1e-3);

    % Solve model with ODE solver
    [VOI, STATES] = ode15s(@(VOI, STATES)computeRates(VOI, STATES, CONSTANTS), tspan, INIT_STATES, options);

    % Compute algebraic variables
    [RATES, ALGEBRAIC] = computeRates(VOI, STATES, CONSTANTS);
    ALGEBRAIC = computeAlgebraic(ALGEBRAIC, CONSTANTS, STATES, VOI);

    vlabels = {'I_pulse in component environment (fA)',...
        'V_m in component environment (volt)',...
        'q_Cai in component environment (fmol)',...
        'q_Ca_TRPN in component environment (fmol)',...
        'tension in component crossbridge_TRPN (N_per_mm2)'};
    [~, i_st, i_alg] = find_indices(vlabels, cellstr(LEGEND_CONSTANTS), cellstr(LEGEND_STATES), cellstr(LEGEND_ALGEBRAIC));
    if i_st
        plot_selected(i_st,VOI,STATES,'s',LEGEND_STATES,'STATES',ceil(sqrt(length(i_st))))
    end
    plot_selected(i_alg,VOI,ALGEBRAIC,'s',LEGEND_ALGEBRAIC,'ALGEBRAIC',ceil(sqrt(length(i_alg))))
end            


function [i_con, i_st, i_alg] = find_indices(labels, LEGEND_CONSTANTS, LEGEND_STATES, LEGEND_ALGEBRAIC)
% return the indices for the selected labels
    all_legends = [LEGEND_CONSTANTS; LEGEND_STATES; LEGEND_ALGEBRAIC];
    
    i_con = [];
    for i = 1:length(labels)
        i_con = [i_con; find(strcmp(labels{i},LEGEND_CONSTANTS))];
    end
    i_st = [];
    for i = 1:length(labels)
        i_st = [i_st; find(strcmp(labels{i},LEGEND_STATES))];
    end
    i_alg = [];
    for i = 1:length(labels)
        i_alg = [i_alg; find(strcmp(labels{i},LEGEND_ALGEBRAIC))];
    end
    
    if length(i_con) + length(i_st) + length(i_alg) < length(labels)
        error('missing index');
    end
end


function [] = plot_selected(ids,x,y,legend_x,legend_y,titlestr,ns)
    istart = 1;
    figure();
%     plot stimuli
    for i = 1:length(ids)
        subplot(ns,ns,i)
        plotting_x = x(istart:end);
        plotting_y = y(istart:end,ids(i));
        if isempty(plotting_y) % probably a constant scalar
            plotting_y = repmat(y(ids(i)),2);
            plotting_x = [x(istart), x(end)];
        end
        plot(plotting_x, plotting_y);
        xlabel('time (s)');
        str = split(legend_y(ids(i),:), ' ');
        str = legend_y(ids(i),:);
        l = legend(str);
        set(l,'interpreter','none');
    end
    suptitle(titlestr)    
end

function [LEGEND_STATES, LEGEND_ALGEBRAIC, LEGEND_VOI, LEGEND_CONSTANTS] = createLegends()
    LEGEND_STATES = ''; LEGEND_ALGEBRAIC = ''; LEGEND_VOI = ''; LEGEND_CONSTANTS = '';
    LEGEND_CONSTANTS(:,1) = strpad('kappa_R_TRPNCa in component BG_parameters (fmol_per_sec)');
    LEGEND_CONSTANTS(:,2) = strpad('kappa_R_BU in component BG_parameters (fmol_per_sec)');
    LEGEND_CONSTANTS(:,3) = strpad('kappa_R_UW in component BG_parameters (fmol_per_sec)');
    LEGEND_CONSTANTS(:,4) = strpad('kappa_R_WS in component BG_parameters (fmol_per_sec)');
    LEGEND_CONSTANTS(:,5) = strpad('kappa_R_SU in component BG_parameters (fmol_per_sec)');
    LEGEND_CONSTANTS(:,6) = strpad('kappa_Ca1 in component BG_parameters (fmol_per_sec)');
    LEGEND_CONSTANTS(:,7) = strpad('kappa_Ca2 in component BG_parameters (fmol_per_sec)');
    LEGEND_CONSTANTS(:,8) = strpad('kappa_K1 in component BG_parameters (fmol_per_sec)');
    LEGEND_CONSTANTS(:,9) = strpad('kappa_K2 in component BG_parameters (fmol_per_sec)');
    LEGEND_CONSTANTS(:,10) = strpad('kappa_d000 in component BG_parameters (fmol_per_sec)');
    LEGEND_CONSTANTS(:,11) = strpad('kappa_d010 in component BG_parameters (fmol_per_sec)');
    LEGEND_CONSTANTS(:,12) = strpad('kappa_d020 in component BG_parameters (fmol_per_sec)');
    LEGEND_CONSTANTS(:,13) = strpad('kappa_d001 in component BG_parameters (fmol_per_sec)');
    LEGEND_CONSTANTS(:,14) = strpad('kappa_d011 in component BG_parameters (fmol_per_sec)');
    LEGEND_CONSTANTS(:,15) = strpad('kappa_d021 in component BG_parameters (fmol_per_sec)');
    LEGEND_CONSTANTS(:,16) = strpad('kappa_f1_000 in component BG_parameters (fmol_per_sec)');
    LEGEND_CONSTANTS(:,17) = strpad('kappa_f1_100 in component BG_parameters (fmol_per_sec)');
    LEGEND_CONSTANTS(:,18) = strpad('kappa_f1_001 in component BG_parameters (fmol_per_sec)');
    LEGEND_CONSTANTS(:,19) = strpad('kappa_f1_101 in component BG_parameters (fmol_per_sec)');
    LEGEND_CONSTANTS(:,20) = strpad('kappa_f2_000 in component BG_parameters (fmol_per_sec)');
    LEGEND_CONSTANTS(:,21) = strpad('kappa_f2_100 in component BG_parameters (fmol_per_sec)');
    LEGEND_CONSTANTS(:,22) = strpad('kappa_f2_001 in component BG_parameters (fmol_per_sec)');
    LEGEND_CONSTANTS(:,23) = strpad('kappa_f2_101 in component BG_parameters (fmol_per_sec)');
    LEGEND_CONSTANTS(:,24) = strpad('kappa_f3_010 in component BG_parameters (fmol_per_sec)');
    LEGEND_CONSTANTS(:,25) = strpad('kappa_f3_110 in component BG_parameters (fmol_per_sec)');
    LEGEND_CONSTANTS(:,26) = strpad('kappa_f3_011 in component BG_parameters (fmol_per_sec)');
    LEGEND_CONSTANTS(:,27) = strpad('kappa_f3_111 in component BG_parameters (fmol_per_sec)');
    LEGEND_CONSTANTS(:,28) = strpad('kappa_fCa000 in component BG_parameters (fmol_per_sec)');
    LEGEND_CONSTANTS(:,29) = strpad('kappa_fCa100 in component BG_parameters (fmol_per_sec)');
    LEGEND_CONSTANTS(:,30) = strpad('kappa_fCa010 in component BG_parameters (fmol_per_sec)');
    LEGEND_CONSTANTS(:,31) = strpad('kappa_fCa110 in component BG_parameters (fmol_per_sec)');
    LEGEND_CONSTANTS(:,32) = strpad('kappa_fCa020 in component BG_parameters (fmol_per_sec)');
    LEGEND_CONSTANTS(:,33) = strpad('kappa_fCa120 in component BG_parameters (fmol_per_sec)');
    LEGEND_CONSTANTS(:,34) = strpad('kappa_PLBph1 in component BG_parameters (fmol_per_sec)');
    LEGEND_CONSTANTS(:,35) = strpad('kappa_PLBph2 in component BG_parameters (fmol_per_sec)');
    LEGEND_CONSTANTS(:,36) = strpad('kappa_PLBd1 in component BG_parameters (fmol_per_sec)');
    LEGEND_CONSTANTS(:,37) = strpad('kappa_PLBd2 in component BG_parameters (fmol_per_sec)');
    LEGEND_CONSTANTS(:,38) = strpad('kappa_Inh in component BG_parameters (fmol_per_sec)');
    LEGEND_CONSTANTS(:,39) = strpad('kappa_RyR in component BG_parameters (fmol_per_sec)');
    LEGEND_CONSTANTS(:,40) = strpad('kappa_OC in component BG_parameters (fmol_per_sec)');
    LEGEND_CONSTANTS(:,41) = strpad('kappa_CCI in component BG_parameters (fmol_per_sec)');
    LEGEND_CONSTANTS(:,42) = strpad('kappa_CII in component BG_parameters (fmol_per_sec)');
    LEGEND_CONSTANTS(:,43) = strpad('kappa_IO in component BG_parameters (fmol_per_sec)');
    LEGEND_CONSTANTS(:,44) = strpad('kappa_SERCA_R1_2 in component BG_parameters (fmol_per_sec)');
    LEGEND_CONSTANTS(:,45) = strpad('kappa_SERCA_R2_4 in component BG_parameters (fmol_per_sec)');
    LEGEND_CONSTANTS(:,46) = strpad('kappa_SERCA_R2_2a in component BG_parameters (fmol_per_sec)');
    LEGEND_CONSTANTS(:,47) = strpad('kappa_SERCA_R4_5 in component BG_parameters (fmol_per_sec)');
    LEGEND_CONSTANTS(:,48) = strpad('kappa_SERCA_R5_6 in component BG_parameters (fmol_per_sec)');
    LEGEND_CONSTANTS(:,49) = strpad('kappa_SERCA_R6_8 in component BG_parameters (fmol_per_sec)');
    LEGEND_CONSTANTS(:,50) = strpad('kappa_SERCA_R8_9 in component BG_parameters (fmol_per_sec)');
    LEGEND_CONSTANTS(:,51) = strpad('kappa_SERCA_R9_10 in component BG_parameters (fmol_per_sec)');
    LEGEND_CONSTANTS(:,52) = strpad('kappa_SERCA_R10_1 in component BG_parameters (fmol_per_sec)');
    LEGEND_CONSTANTS(:,53) = strpad('K_TRPN in component BG_parameters (per_fmol)');
    LEGEND_CONSTANTS(:,54) = strpad('K_Cai in component BG_parameters (per_fmol)');
    LEGEND_CONSTANTS(:,55) = strpad('K_Ca_TRPN in component BG_parameters (per_fmol)');
    LEGEND_CONSTANTS(:,56) = strpad('K_B in component BG_parameters (per_fmol)');
    LEGEND_CONSTANTS(:,57) = strpad('K_U in component BG_parameters (per_fmol)');
    LEGEND_CONSTANTS(:,58) = strpad('K_W in component BG_parameters (per_fmol)');
    LEGEND_CONSTANTS(:,59) = strpad('K_S in component BG_parameters (per_fmol)');
    LEGEND_CONSTANTS(:,60) = strpad('K_Cao in component BG_parameters (per_fmol)');
    LEGEND_CONSTANTS(:,61) = strpad('K_Ki in component BG_parameters (per_fmol)');
    LEGEND_CONSTANTS(:,62) = strpad('K_Ko in component BG_parameters (per_fmol)');
    LEGEND_CONSTANTS(:,63) = strpad('K_000_LCC in component BG_parameters (per_fmol)');
    LEGEND_CONSTANTS(:,64) = strpad('K_010_LCC in component BG_parameters (per_fmol)');
    LEGEND_CONSTANTS(:,65) = strpad('K_020_LCC in component BG_parameters (per_fmol)');
    LEGEND_CONSTANTS(:,66) = strpad('K_100_LCC in component BG_parameters (per_fmol)');
    LEGEND_CONSTANTS(:,67) = strpad('K_110_LCC in component BG_parameters (per_fmol)');
    LEGEND_CONSTANTS(:,68) = strpad('K_120_LCC in component BG_parameters (per_fmol)');
    LEGEND_CONSTANTS(:,69) = strpad('K_001_LCC in component BG_parameters (per_fmol)');
    LEGEND_CONSTANTS(:,70) = strpad('K_011_LCC in component BG_parameters (per_fmol)');
    LEGEND_CONSTANTS(:,71) = strpad('K_021_LCC in component BG_parameters (per_fmol)');
    LEGEND_CONSTANTS(:,72) = strpad('K_101_LCC in component BG_parameters (per_fmol)');
    LEGEND_CONSTANTS(:,73) = strpad('K_111_LCC in component BG_parameters (per_fmol)');
    LEGEND_CONSTANTS(:,74) = strpad('K_121_LCC in component BG_parameters (per_fmol)');
    LEGEND_CONSTANTS(:,75) = strpad('K_PLB in component BG_parameters (per_fmol)');
    LEGEND_CONSTANTS(:,76) = strpad('K_PKACI in component BG_parameters (per_fmol)');
    LEGEND_CONSTANTS(:,77) = strpad('K_PLB_PKACI in component BG_parameters (per_fmol)');
    LEGEND_CONSTANTS(:,78) = strpad('K_PP1 in component BG_parameters (per_fmol)');
    LEGEND_CONSTANTS(:,79) = strpad('K_PLBp_PP1 in component BG_parameters (per_fmol)');
    LEGEND_CONSTANTS(:,80) = strpad('K_PLBp in component BG_parameters (per_fmol)');
    LEGEND_CONSTANTS(:,81) = strpad('K_Ip in component BG_parameters (per_fmol)');
    LEGEND_CONSTANTS(:,82) = strpad('K_Ip_PP1 in component BG_parameters (per_fmol)');
    LEGEND_CONSTANTS(:,83) = strpad('K_Ca_SR in component BG_parameters (per_fmol)');
    LEGEND_CONSTANTS(:,84) = strpad('K_C_RyR in component BG_parameters (per_fmol)');
    LEGEND_CONSTANTS(:,85) = strpad('K_CI_RyR in component BG_parameters (per_fmol)');
    LEGEND_CONSTANTS(:,86) = strpad('K_I_RyR in component BG_parameters (per_fmol)');
    LEGEND_CONSTANTS(:,87) = strpad('K_O_RyR in component BG_parameters (per_fmol)');
    LEGEND_CONSTANTS(:,88) = strpad('K_P1_SERCA in component BG_parameters (per_fmol)');
    LEGEND_CONSTANTS(:,89) = strpad('K_P2_SERCA in component BG_parameters (per_fmol)');
    LEGEND_CONSTANTS(:,90) = strpad('K_P2a_SERCA in component BG_parameters (per_fmol)');
    LEGEND_CONSTANTS(:,91) = strpad('K_P4_SERCA in component BG_parameters (per_fmol)');
    LEGEND_CONSTANTS(:,92) = strpad('K_P5_SERCA in component BG_parameters (per_fmol)');
    LEGEND_CONSTANTS(:,93) = strpad('K_P6_SERCA in component BG_parameters (per_fmol)');
    LEGEND_CONSTANTS(:,94) = strpad('K_P8_SERCA in component BG_parameters (per_fmol)');
    LEGEND_CONSTANTS(:,95) = strpad('K_P9_SERCA in component BG_parameters (per_fmol)');
    LEGEND_CONSTANTS(:,96) = strpad('K_P10_SERCA in component BG_parameters (per_fmol)');
    LEGEND_CONSTANTS(:,97) = strpad('K_H in component BG_parameters (per_fmol)');
    LEGEND_CONSTANTS(:,98) = strpad('K_MgATP in component BG_parameters (per_fmol)');
    LEGEND_CONSTANTS(:,99) = strpad('K_MgADP in component BG_parameters (per_fmol)');
    LEGEND_CONSTANTS(:,100) = strpad('K_P in component BG_parameters (per_fmol)');
    LEGEND_VOI = strpad('time in component environment (second)');
    LEGEND_CONSTANTS(:,101) = strpad('vol_myo in component environment (pL)');
    LEGEND_CONSTANTS(:,102) = strpad('freq in component environment (dimensionless)');
    LEGEND_ALGEBRAIC(:,224) = strpad('v_RyR in component RyR (fmol_per_sec)');
    LEGEND_CONSTANTS(:,103) = strpad('C_m in component environment (fF)');
    LEGEND_CONSTANTS(:,104) = strpad('F in component constants (C_per_mol)');
    LEGEND_STATES(:,1) = strpad('q_membrane in component environment (fC)');
    LEGEND_ALGEBRAIC(:,44) = strpad('V_m in component environment (volt)');
    LEGEND_CONSTANTS(:,105) = strpad('q_TRPN_init in component environment (fmol)');
    LEGEND_CONSTANTS(:,106) = strpad('q_Ca_TRPN_init in component environment (fmol)');
    LEGEND_CONSTANTS(:,107) = strpad('q_Cai_init in component environment (fmol)');
    LEGEND_CONSTANTS(:,108) = strpad('q_B_init in component environment (fmol)');
    LEGEND_CONSTANTS(:,109) = strpad('q_U_init in component environment (fmol)');
    LEGEND_CONSTANTS(:,110) = strpad('q_W_init in component environment (fmol)');
    LEGEND_CONSTANTS(:,111) = strpad('q_S_init in component environment (fmol)');
    LEGEND_CONSTANTS(:,112) = strpad('q_Cao_init in component environment (fmol)');
    LEGEND_CONSTANTS(:,113) = strpad('q_Ki_init in component environment (fmol)');
    LEGEND_CONSTANTS(:,114) = strpad('q_Ko_init in component environment (fmol)');
    LEGEND_CONSTANTS(:,115) = strpad('q_PLB_init in component environment (fmol)');
    LEGEND_CONSTANTS(:,116) = strpad('q_PKACI_init in component environment (fmol)');
    LEGEND_CONSTANTS(:,117) = strpad('q_PLB_PKACI_init in component environment (fmol)');
    LEGEND_CONSTANTS(:,118) = strpad('q_PP1_init in component environment (fmol)');
    LEGEND_CONSTANTS(:,119) = strpad('q_PLBp_PP1_init in component environment (fmol)');
    LEGEND_CONSTANTS(:,120) = strpad('q_PLBp_init in component environment (fmol)');
    LEGEND_CONSTANTS(:,121) = strpad('q_Ip_init in component environment (fmol)');
    LEGEND_CONSTANTS(:,122) = strpad('q_Ip_PP1_init in component environment (fmol)');
    LEGEND_CONSTANTS(:,123) = strpad('q_Ca_SR_init in component environment (fmol)');
    LEGEND_CONSTANTS(:,124) = strpad('q_H_init in component environment (fmol)');
    LEGEND_CONSTANTS(:,125) = strpad('q_P_init in component environment (fmol)');
    LEGEND_CONSTANTS(:,126) = strpad('q_MgADP_init in component environment (fmol)');
    LEGEND_CONSTANTS(:,127) = strpad('q_MgATP_init in component environment (fmol)');
    LEGEND_ALGEBRAIC(:,4) = strpad('q_TRPN in component environment (fmol)');
    LEGEND_ALGEBRAIC(:,14) = strpad('q_Cai in component environment (fmol)');
    LEGEND_ALGEBRAIC(:,18) = strpad('q_Ca_TRPN in component environment (fmol)');
    LEGEND_ALGEBRAIC(:,22) = strpad('q_B in component environment (fmol)');
    LEGEND_ALGEBRAIC(:,25) = strpad('q_U in component environment (fmol)');
    LEGEND_ALGEBRAIC(:,29) = strpad('q_W in component environment (fmol)');
    LEGEND_ALGEBRAIC(:,34) = strpad('q_S in component environment (fmol)');
    LEGEND_ALGEBRAIC(:,20) = strpad('q_Cao in component environment (fmol)');
    LEGEND_ALGEBRAIC(:,24) = strpad('q_Ki in component environment (fmol)');
    LEGEND_ALGEBRAIC(:,27) = strpad('q_Ko in component environment (fmol)');
    LEGEND_ALGEBRAIC(:,1) = strpad('q_PLB in component environment (fmol)');
    LEGEND_ALGEBRAIC(:,11) = strpad('q_PKACI in component environment (fmol)');
    LEGEND_ALGEBRAIC(:,15) = strpad('q_PLB_PKACI in component environment (fmol)');
    LEGEND_ALGEBRAIC(:,19) = strpad('q_PP1 in component environment (fmol)');
    LEGEND_ALGEBRAIC(:,23) = strpad('q_PLBp_PP1 in component environment (fmol)');
    LEGEND_ALGEBRAIC(:,26) = strpad('q_PLBp in component environment (fmol)');
    LEGEND_ALGEBRAIC(:,30) = strpad('q_Ip in component environment (fmol)');
    LEGEND_ALGEBRAIC(:,35) = strpad('q_Ip_PP1 in component environment (fmol)');
    LEGEND_ALGEBRAIC(:,31) = strpad('q_Ca_SR in component environment (fmol)');
    LEGEND_ALGEBRAIC(:,36) = strpad('q_H in component environment (fmol)');
    LEGEND_ALGEBRAIC(:,40) = strpad('q_MgATP in component environment (fmol)');
    LEGEND_ALGEBRAIC(:,47) = strpad('q_MgADP in component environment (fmol)');
    LEGEND_ALGEBRAIC(:,52) = strpad('q_P in component environment (fmol)');
    LEGEND_STATES(:,2) = strpad('q_TRPN in component crossbridge_TRPN (fmol)');
    LEGEND_STATES(:,3) = strpad('q_Cai in component crossbridge_TRPN (fmol)');
    LEGEND_STATES(:,4) = strpad('q_Ca_TRPN in component crossbridge_TRPN (fmol)');
    LEGEND_STATES(:,5) = strpad('q_B in component crossbridge_TRPN (fmol)');
    LEGEND_STATES(:,6) = strpad('q_U in component crossbridge_TRPN (fmol)');
    LEGEND_STATES(:,7) = strpad('q_W in component crossbridge_TRPN (fmol)');
    LEGEND_STATES(:,8) = strpad('q_S in component crossbridge_TRPN (fmol)');
    LEGEND_ALGEBRAIC(:,96) = strpad('T_total in component crossbridge_TRPN (kPa)');
    LEGEND_STATES(:,9) = strpad('SL in component crossbridge_TRPN (metre)');
    LEGEND_STATES(:,10) = strpad('q_Cai in component LCC (fmol)');
    LEGEND_STATES(:,11) = strpad('q_Cao in component LCC (fmol)');
    LEGEND_STATES(:,12) = strpad('q_Ki in component LCC (fmol)');
    LEGEND_STATES(:,13) = strpad('q_Ko in component LCC (fmol)');
    LEGEND_ALGEBRAIC(:,163) = strpad('v_Ca_fgate in component LCC (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,37) = strpad('q_Ca_fgate in component LCC_gate (fmol)');
    LEGEND_STATES(:,14) = strpad('q_PLB in component PLB (fmol)');
    LEGEND_STATES(:,15) = strpad('q_PKACI in component PLB (fmol)');
    LEGEND_STATES(:,16) = strpad('q_PLB_PKACI in component PLB (fmol)');
    LEGEND_STATES(:,17) = strpad('q_PP1 in component PLB (fmol)');
    LEGEND_STATES(:,18) = strpad('q_PLBp_PP1 in component PLB (fmol)');
    LEGEND_STATES(:,19) = strpad('q_PLBp in component PLB (fmol)');
    LEGEND_STATES(:,20) = strpad('q_Ip in component PLB (fmol)');
    LEGEND_STATES(:,21) = strpad('q_Ip_PP1 in component PLB (fmol)');
    LEGEND_STATES(:,22) = strpad('q_Ca_SR in component RyR (fmol)');
    LEGEND_STATES(:,23) = strpad('q_Cai in component RyR (fmol)');
    LEGEND_ALGEBRAIC(:,41) = strpad('q_Ca_gate_complexes in component RyR_gate (fmol)');
    LEGEND_STATES(:,24) = strpad('q_H in component SERCA (fmol)');
    LEGEND_STATES(:,25) = strpad('q_Cai in component SERCA (fmol)');
    LEGEND_STATES(:,26) = strpad('q_Ca_SR in component SERCA (fmol)');
    LEGEND_STATES(:,27) = strpad('q_MgATP in component SERCA (fmol)');
    LEGEND_STATES(:,28) = strpad('q_MgADP in component SERCA (fmol)');
    LEGEND_STATES(:,29) = strpad('q_P in component SERCA (fmol)');
    LEGEND_ALGEBRAIC(:,48) = strpad('q_SERCA_Ca_complexes in component SERCA (fmol)');
    LEGEND_ALGEBRAIC(:,39) = strpad('I_pulse in component environment (fA)');
    LEGEND_CONSTANTS(:,128) = strpad('pulse_start in component environment (second)');
    LEGEND_CONSTANTS(:,129) = strpad('pulse_end in component environment (second)');
    LEGEND_CONSTANTS(:,130) = strpad('pulseMag in component environment (fA)');
    LEGEND_CONSTANTS(:,131) = strpad('pulseHolding in component environment (fA)');
    LEGEND_ALGEBRAIC(:,225) = strpad('v_E_RyR in component environment (fA)');
    LEGEND_ALGEBRAIC(:,217) = strpad('v_E_LCC in component LCC (fA)');
    LEGEND_ALGEBRAIC(:,227) = strpad('sum_I in component environment (fA)');
    LEGEND_CONSTANTS(:,132) = strpad('zCa in component ion_valences (dimensionless)');
    LEGEND_CONSTANTS(:,133) = strpad('zK in component ion_valences (dimensionless)');
    LEGEND_ALGEBRAIC(:,53) = strpad('Ca_T in component environment (fmol)');
    LEGEND_ALGEBRAIC(:,32) = strpad('PLB_T in component environment (fmol)');
    LEGEND_ALGEBRAIC(:,21) = strpad('PKACI_T in component environment (fmol)');
    LEGEND_ALGEBRAIC(:,42) = strpad('Ip_T in component environment (fmol)');
    LEGEND_ALGEBRAIC(:,28) = strpad('K_i_T in component environment (fmol)');
    LEGEND_ALGEBRAIC(:,33) = strpad('K_o_T in component environment (fmol)');
    LEGEND_CONSTANTS(:,134) = strpad('R in component constants (J_per_K_per_mol)');
    LEGEND_CONSTANTS(:,135) = strpad('T in component constants (kelvin)');
    LEGEND_CONSTANTS(:,136) = strpad('zNa in component ion_valences (dimensionless)');
    LEGEND_CONSTANTS(:,137) = strpad('zCl in component ion_valences (dimensionless)');
    LEGEND_CONSTANTS(:,138) = strpad('n_Tm in component crossbridge_TRPN (dimensionless)');
    LEGEND_ALGEBRAIC(:,38) = strpad('mu_TRPN in component crossbridge_TRPN (J_per_mol)');
    LEGEND_ALGEBRAIC(:,43) = strpad('mu_Cai in component crossbridge_TRPN (J_per_mol)');
    LEGEND_ALGEBRAIC(:,49) = strpad('mu_Ca_TRPN in component crossbridge_TRPN (J_per_mol)');
    LEGEND_ALGEBRAIC(:,54) = strpad('mu_B in component crossbridge_TRPN (J_per_mol)');
    LEGEND_ALGEBRAIC(:,58) = strpad('mu_U in component crossbridge_TRPN (J_per_mol)');
    LEGEND_ALGEBRAIC(:,63) = strpad('mu_W in component crossbridge_TRPN (J_per_mol)');
    LEGEND_ALGEBRAIC(:,68) = strpad('mu_S in component crossbridge_TRPN (J_per_mol)');
    LEGEND_ALGEBRAIC(:,108) = strpad('v_R_TRPNCa in component crossbridge_TRPN (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,73) = strpad('v_R_BU in component crossbridge_TRPN (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,82) = strpad('v_R_UW in component crossbridge_TRPN (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,87) = strpad('v_R_WS in component crossbridge_TRPN (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,92) = strpad('v_R_SU in component crossbridge_TRPN (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,100) = strpad('tension in component crossbridge_TRPN (N_per_mm2)');
    LEGEND_ALGEBRAIC(:,104) = strpad('mu_tension in component crossbridge_TRPN (J_per_mol)');
    LEGEND_CONSTANTS(:,139) = strpad('kf_coeff in component crossbridge_TRPN (dimensionless)');
    LEGEND_CONSTANTS(:,174) = strpad('n in component crossbridge_TRPN (J_per_mol)');
    LEGEND_CONSTANTS(:,140) = strpad('hh in component crossbridge_TRPN (mm2_per_N)');
    LEGEND_CONSTANTS(:,141) = strpad('SL_0 in component crossbridge_TRPN (metre)');
    LEGEND_CONSTANTS(:,142) = strpad('q_MS in component crossbridge_TRPN (fmol)');
    LEGEND_CONSTANTS(:,143) = strpad('r_s in component crossbridge_TRPN (dimensionless)');
    LEGEND_CONSTANTS(:,144) = strpad('r_w in component crossbridge_TRPN (dimensionless)');
    LEGEND_CONSTANTS(:,145) = strpad('A_eff in component crossbridge_TRPN (dimensionless)');
    LEGEND_CONSTANTS(:,146) = strpad('phi in component crossbridge_TRPN (dimensionless)');
    LEGEND_CONSTANTS(:,147) = strpad('k_uw in component crossbridge_TRPN (per_sec)');
    LEGEND_CONSTANTS(:,148) = strpad('k_ws in component crossbridge_TRPN (per_sec)');
    LEGEND_STATES(:,30) = strpad('G_w in component crossbridge_TRPN (metre)');
    LEGEND_STATES(:,31) = strpad('G_s in component crossbridge_TRPN (metre)');
    LEGEND_CONSTANTS(:,171) = strpad('c_w in component crossbridge_TRPN (per_sec)');
    LEGEND_CONSTANTS(:,172) = strpad('c_s in component crossbridge_TRPN (per_sec)');
    LEGEND_CONSTANTS(:,173) = strpad('A_w in component crossbridge_TRPN (dimensionless)');
    LEGEND_CONSTANTS(:,176) = strpad('A_s in component crossbridge_TRPN (dimensionless)');
    LEGEND_ALGEBRAIC(:,12) = strpad('mu_1 in component crossbridge_TRPN (J_per_m)');
    LEGEND_CONSTANTS(:,177) = strpad('mu_2 in component crossbridge_TRPN (J_per_m)');
    LEGEND_ALGEBRAIC(:,2) = strpad('mu_3 in component crossbridge_TRPN (J_per_m)');
    LEGEND_ALGEBRAIC(:,13) = strpad('mu_4 in component crossbridge_TRPN (J_per_m)');
    LEGEND_CONSTANTS(:,180) = strpad('mu_5 in component crossbridge_TRPN (J_per_m)');
    LEGEND_ALGEBRAIC(:,3) = strpad('mu_6 in component crossbridge_TRPN (J_per_m)');
    LEGEND_ALGEBRAIC(:,16) = strpad('v_1 in component crossbridge_TRPN (m_per_s)');
    LEGEND_CONSTANTS(:,149) = strpad('v_2 in component crossbridge_TRPN (m_per_s)');
    LEGEND_ALGEBRAIC(:,17) = strpad('v_4 in component crossbridge_TRPN (m_per_s)');
    LEGEND_CONSTANTS(:,150) = strpad('v_to_mu in component crossbridge_TRPN (Js_per_m2)');
    LEGEND_ALGEBRAIC(:,69) = strpad('T_active in component crossbridge_TRPN (kPa)');
    LEGEND_CONSTANTS(:,151) = strpad('T_ref in component crossbridge_TRPN (kPa)');
    LEGEND_ALGEBRAIC(:,64) = strpad('mu_T_a in component crossbridge_TRPN (kPa)');
    LEGEND_ALGEBRAIC(:,55) = strpad('mu_T_S in component crossbridge_TRPN (kPa)');
    LEGEND_ALGEBRAIC(:,59) = strpad('mu_T_W in component crossbridge_TRPN (kPa)');
    LEGEND_STATES(:,32) = strpad('Cdd in component crossbridge_TRPN (metre)');
    LEGEND_ALGEBRAIC(:,74) = strpad('eta in component crossbridge_TRPN (per_sec)');
    LEGEND_CONSTANTS(:,152) = strpad('eta_l in component crossbridge_TRPN (per_sec)');
    LEGEND_CONSTANTS(:,153) = strpad('eta_s in component crossbridge_TRPN (per_sec)');
    LEGEND_CONSTANTS(:,154) = strpad('k in component crossbridge_TRPN (dimensionless)');
    LEGEND_CONSTANTS(:,155) = strpad('alpha in component crossbridge_TRPN (kPa)');
    LEGEND_ALGEBRAIC(:,81) = strpad('v_Cdd in component crossbridge_TRPN (m_per_s)');
    LEGEND_ALGEBRAIC(:,75) = strpad('mu_d in component crossbridge_TRPN (J_per_m)');
    LEGEND_ALGEBRAIC(:,76) = strpad('mu_k in component crossbridge_TRPN (J_per_m)');
    LEGEND_ALGEBRAIC(:,77) = strpad('mu_f in component crossbridge_TRPN (J_per_m)');
    LEGEND_ALGEBRAIC(:,86) = strpad('mu_T_passive in component crossbridge_TRPN (kPa)');
    LEGEND_ALGEBRAIC(:,91) = strpad('T_passive in component crossbridge_TRPN (kPa)');
    LEGEND_CONSTANTS(:,178) = strpad('RT in component LCC (J_per_mol)');
    LEGEND_ALGEBRAIC(:,50) = strpad('mu_E in component LCC (J_per_C)');
    LEGEND_ALGEBRAIC(:,78) = strpad('mu_mem_Ca in component LCC (J_per_mol)');
    LEGEND_ALGEBRAIC(:,83) = strpad('mu_mem_K in component LCC (J_per_mol)');
    LEGEND_ALGEBRAIC(:,168) = strpad('v_CaGHK_i in component LCC (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,145) = strpad('v_CaGHK_o in component LCC (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,148) = strpad('v_KGHK_i in component LCC (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,149) = strpad('v_KGHK_o in component LCC (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,56) = strpad('mu_Cai in component LCC (J_per_mol)');
    LEGEND_ALGEBRAIC(:,60) = strpad('mu_Cao in component LCC (J_per_mol)');
    LEGEND_ALGEBRAIC(:,65) = strpad('mu_Ki in component LCC (J_per_mol)');
    LEGEND_ALGEBRAIC(:,70) = strpad('mu_Ko in component LCC (J_per_mol)');
    LEGEND_ALGEBRAIC(:,117) = strpad('mu_S111 in component LCC_gate (J_per_mol)');
    LEGEND_ALGEBRAIC(:,133) = strpad('mu_S121 in component LCC_gate (J_per_mol)');
    LEGEND_ALGEBRAIC(:,119) = strpad('Af_Ca1 in component LCC (J_per_mol)');
    LEGEND_ALGEBRAIC(:,121) = strpad('Ar_Ca1 in component LCC (J_per_mol)');
    LEGEND_ALGEBRAIC(:,127) = strpad('v_Ca1 in component LCC (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,143) = strpad('v_Ca2 in component LCC (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,129) = strpad('v_K1 in component LCC (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,146) = strpad('v_K2 in component LCC (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,135) = strpad('Af_Ca2 in component LCC (J_per_mol)');
    LEGEND_ALGEBRAIC(:,137) = strpad('Ar_Ca2 in component LCC (J_per_mol)');
    LEGEND_ALGEBRAIC(:,123) = strpad('Af_K1 in component LCC (J_per_mol)');
    LEGEND_ALGEBRAIC(:,125) = strpad('Ar_K1 in component LCC (J_per_mol)');
    LEGEND_ALGEBRAIC(:,139) = strpad('Af_K2 in component LCC (J_per_mol)');
    LEGEND_ALGEBRAIC(:,141) = strpad('Ar_K2 in component LCC (J_per_mol)');
    LEGEND_ALGEBRAIC(:,150) = strpad('v_fCa00 in component LCC_gate (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,152) = strpad('v_fCa01 in component LCC_gate (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,154) = strpad('v_fCa02 in component LCC_gate (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,156) = strpad('v_fCa10 in component LCC_gate (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,158) = strpad('v_fCa11 in component LCC_gate (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,160) = strpad('v_fCa12 in component LCC_gate (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,216) = strpad('v_gate in component LCC_gate (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,45) = strpad('v_pulse in component LCC (fmol_per_sec)');
    LEGEND_STATES(:,33) = strpad('q_S000 in component LCC_gate (fmol)');
    LEGEND_STATES(:,34) = strpad('q_S010 in component LCC_gate (fmol)');
    LEGEND_STATES(:,35) = strpad('q_S020 in component LCC_gate (fmol)');
    LEGEND_STATES(:,36) = strpad('q_S100 in component LCC_gate (fmol)');
    LEGEND_STATES(:,37) = strpad('q_S110 in component LCC_gate (fmol)');
    LEGEND_STATES(:,38) = strpad('q_S120 in component LCC_gate (fmol)');
    LEGEND_STATES(:,39) = strpad('q_S001 in component LCC_gate (fmol)');
    LEGEND_STATES(:,40) = strpad('q_S011 in component LCC_gate (fmol)');
    LEGEND_STATES(:,41) = strpad('q_S021 in component LCC_gate (fmol)');
    LEGEND_STATES(:,42) = strpad('q_S101 in component LCC_gate (fmol)');
    LEGEND_STATES(:,43) = strpad('q_S111 in component LCC_gate (fmol)');
    LEGEND_STATES(:,44) = strpad('q_S121 in component LCC_gate (fmol)');
    LEGEND_ALGEBRAIC(:,88) = strpad('mu_S000 in component LCC_gate (J_per_mol)');
    LEGEND_ALGEBRAIC(:,97) = strpad('mu_S010 in component LCC_gate (J_per_mol)');
    LEGEND_ALGEBRAIC(:,105) = strpad('mu_S020 in component LCC_gate (J_per_mol)');
    LEGEND_ALGEBRAIC(:,111) = strpad('mu_S100 in component LCC_gate (J_per_mol)');
    LEGEND_ALGEBRAIC(:,115) = strpad('mu_S110 in component LCC_gate (J_per_mol)');
    LEGEND_ALGEBRAIC(:,131) = strpad('mu_S120 in component LCC_gate (J_per_mol)');
    LEGEND_ALGEBRAIC(:,93) = strpad('mu_S001 in component LCC_gate (J_per_mol)');
    LEGEND_ALGEBRAIC(:,101) = strpad('mu_S011 in component LCC_gate (J_per_mol)');
    LEGEND_ALGEBRAIC(:,109) = strpad('mu_S021 in component LCC_gate (J_per_mol)');
    LEGEND_ALGEBRAIC(:,113) = strpad('mu_S101 in component LCC_gate (J_per_mol)');
    LEGEND_ALGEBRAIC(:,187) = strpad('v_f1_000 in component LCC_gate (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,190) = strpad('v_f2_000 in component LCC_gate (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,194) = strpad('v_f3_010 in component LCC_gate (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,196) = strpad('v_f1_100 in component LCC_gate (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,198) = strpad('v_f2_100 in component LCC_gate (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,200) = strpad('v_f3_110 in component LCC_gate (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,164) = strpad('v_d000 in component LCC_gate (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,169) = strpad('v_d010 in component LCC_gate (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,172) = strpad('v_d020 in component LCC_gate (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,175) = strpad('v_d001 in component LCC_gate (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,179) = strpad('v_d011 in component LCC_gate (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,183) = strpad('v_d021 in component LCC_gate (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,202) = strpad('v_f1_001 in component LCC_gate (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,205) = strpad('v_f2_001 in component LCC_gate (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,206) = strpad('v_f3_011 in component LCC_gate (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,208) = strpad('v_f1_101 in component LCC_gate (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,210) = strpad('v_f2_101 in component LCC_gate (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,212) = strpad('v_f3_111 in component LCC_gate (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,195) = strpad('v_S000 in component LCC_gate (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,199) = strpad('v_S010 in component LCC_gate (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,197) = strpad('v_S020 in component LCC_gate (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,201) = strpad('v_S100 in component LCC_gate (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,203) = strpad('v_S110 in component LCC_gate (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,204) = strpad('v_S120 in component LCC_gate (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,207) = strpad('v_S001 in component LCC_gate (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,211) = strpad('v_S011 in component LCC_gate (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,209) = strpad('v_S021 in component LCC_gate (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,213) = strpad('v_S101 in component LCC_gate (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,214) = strpad('v_S111 in component LCC_gate (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,215) = strpad('v_S121 in component LCC_gate (fmol_per_sec)');
    LEGEND_CONSTANTS(:,156) = strpad('z_rCa in component LCC_gate (dimensionless)');
    LEGEND_CONSTANTS(:,157) = strpad('z_fd in component LCC_gate (dimensionless)');
    LEGEND_CONSTANTS(:,158) = strpad('z_ff1 in component LCC_gate (dimensionless)');
    LEGEND_CONSTANTS(:,159) = strpad('z_ff2 in component LCC_gate (dimensionless)');
    LEGEND_CONSTANTS(:,160) = strpad('z_ff3 in component LCC_gate (dimensionless)');
    LEGEND_CONSTANTS(:,161) = strpad('z_rd in component LCC_gate (dimensionless)');
    LEGEND_CONSTANTS(:,162) = strpad('z_rf1 in component LCC_gate (dimensionless)');
    LEGEND_CONSTANTS(:,163) = strpad('z_rf2 in component LCC_gate (dimensionless)');
    LEGEND_CONSTANTS(:,164) = strpad('z_rf3 in component LCC_gate (dimensionless)');
    LEGEND_ALGEBRAIC(:,89) = strpad('vPLBph1 in component PLB (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,94) = strpad('vPLBph2 in component PLB (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,98) = strpad('vPLBd1 in component PLB (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,102) = strpad('vPLBd2 in component PLB (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,106) = strpad('vInh in component PLB (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,46) = strpad('mu_PLB in component PLB (J_per_mol)');
    LEGEND_ALGEBRAIC(:,51) = strpad('mu_PKACI in component PLB (J_per_mol)');
    LEGEND_ALGEBRAIC(:,57) = strpad('mu_PLB_PKACI in component PLB (J_per_mol)');
    LEGEND_ALGEBRAIC(:,61) = strpad('mu_PP1 in component PLB (J_per_mol)');
    LEGEND_ALGEBRAIC(:,66) = strpad('mu_PLBp_PP1 in component PLB (J_per_mol)');
    LEGEND_ALGEBRAIC(:,71) = strpad('mu_PLBp in component PLB (J_per_mol)');
    LEGEND_ALGEBRAIC(:,79) = strpad('mu_Ip in component PLB (J_per_mol)');
    LEGEND_ALGEBRAIC(:,84) = strpad('mu_Ip_PP1 in component PLB (J_per_mol)');
    LEGEND_CONSTANTS(:,165) = strpad('nCa_1 in component RyR (dimensionless)');
    LEGEND_CONSTANTS(:,166) = strpad('nCa_2 in component RyR (dimensionless)');
    LEGEND_ALGEBRAIC(:,218) = strpad('mu_Ca_SR in component RyR (J_per_mol)');
    LEGEND_ALGEBRAIC(:,219) = strpad('mu_Cai in component RyR (J_per_mol)');
    LEGEND_ALGEBRAIC(:,231) = strpad('v_gate_Cai in component RyR (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,223) = strpad('mu_O_RyR in component RyR_gate (J_per_mol)');
    LEGEND_ALGEBRAIC(:,226) = strpad('v_OC in component RyR_gate (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,228) = strpad('v_CCI in component RyR_gate (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,229) = strpad('v_CII in component RyR_gate (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,230) = strpad('v_IO in component RyR_gate (fmol_per_sec)');
    LEGEND_STATES(:,45) = strpad('q_C_RyR in component RyR_gate (fmol)');
    LEGEND_STATES(:,46) = strpad('q_CI_RyR in component RyR_gate (fmol)');
    LEGEND_STATES(:,47) = strpad('q_I_RyR in component RyR_gate (fmol)');
    LEGEND_STATES(:,48) = strpad('q_O_RyR in component RyR_gate (fmol)');
    LEGEND_ALGEBRAIC(:,220) = strpad('mu_C_RyR in component RyR_gate (J_per_mol)');
    LEGEND_ALGEBRAIC(:,221) = strpad('mu_CI_RyR in component RyR_gate (J_per_mol)');
    LEGEND_ALGEBRAIC(:,222) = strpad('mu_I_RyR in component RyR_gate (J_per_mol)');
    LEGEND_CONSTANTS(:,167) = strpad('n_Cai in component SERCA (dimensionless)');
    LEGEND_CONSTANTS(:,168) = strpad('n_Ca_SR in component SERCA (dimensionless)');
    LEGEND_CONSTANTS(:,169) = strpad('n_H in component SERCA (dimensionless)');
    LEGEND_STATES(:,49) = strpad('q_P1_SERCA in component SERCA (fmol)');
    LEGEND_STATES(:,50) = strpad('q_P2_SERCA in component SERCA (fmol)');
    LEGEND_STATES(:,51) = strpad('q_P2a_SERCA in component SERCA (fmol)');
    LEGEND_STATES(:,52) = strpad('q_P4_SERCA in component SERCA (fmol)');
    LEGEND_STATES(:,53) = strpad('q_P5_SERCA in component SERCA (fmol)');
    LEGEND_STATES(:,54) = strpad('q_P10_SERCA in component SERCA (fmol)');
    LEGEND_STATES(:,55) = strpad('q_P6_SERCA in component SERCA (fmol)');
    LEGEND_STATES(:,56) = strpad('q_P8_SERCA in component SERCA (fmol)');
    LEGEND_STATES(:,57) = strpad('q_P9_SERCA in component SERCA (fmol)');
    LEGEND_ALGEBRAIC(:,5) = strpad('c_Cai in component SERCA (mM)');
    LEGEND_ALGEBRAIC(:,6) = strpad('c_Ca_SR in component SERCA (mM)');
    LEGEND_ALGEBRAIC(:,7) = strpad('c_H in component SERCA (mM)');
    LEGEND_ALGEBRAIC(:,8) = strpad('c_MgADP in component SERCA (mM)');
    LEGEND_ALGEBRAIC(:,9) = strpad('c_MgATP in component SERCA (mM)');
    LEGEND_ALGEBRAIC(:,10) = strpad('c_P in component SERCA (mM)');
    LEGEND_CONSTANTS(:,170) = strpad('vol_i in component SERCA (pL)');
    LEGEND_CONSTANTS(:,175) = strpad('vol_sr in component SERCA (pL)');
    LEGEND_CONSTANTS(:,179) = strpad('vol_isr in component SERCA (pL)');
    LEGEND_ALGEBRAIC(:,62) = strpad('mu_Cai in component SERCA (J_per_mol)');
    LEGEND_ALGEBRAIC(:,176) = strpad('v_Cai in component SERCA (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,67) = strpad('mu_Ca_SR in component SERCA (J_per_mol)');
    LEGEND_ALGEBRAIC(:,184) = strpad('v_Ca_SR in component SERCA (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,72) = strpad('mu_H in component SERCA (J_per_mol)');
    LEGEND_ALGEBRAIC(:,191) = strpad('v_H in component SERCA (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,80) = strpad('mu_MgADP in component SERCA (J_per_mol)');
    LEGEND_ALGEBRAIC(:,170) = strpad('v_MgADP in component SERCA (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,85) = strpad('mu_MgATP in component SERCA (J_per_mol)');
    LEGEND_ALGEBRAIC(:,165) = strpad('v_MgATP in component SERCA (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,95) = strpad('mu_P1 in component SERCA (J_per_mol)');
    LEGEND_ALGEBRAIC(:,166) = strpad('v_P1 in component SERCA (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,90) = strpad('mu_P in component SERCA (J_per_mol)');
    LEGEND_ALGEBRAIC(:,161) = strpad('v_P in component SERCA (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,99) = strpad('mu_P2 in component SERCA (J_per_mol)');
    LEGEND_ALGEBRAIC(:,177) = strpad('v_P2 in component SERCA (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,103) = strpad('mu_P2a in component SERCA (J_per_mol)');
    LEGEND_ALGEBRAIC(:,173) = strpad('v_P2a in component SERCA (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,107) = strpad('mu_P4 in component SERCA (J_per_mol)');
    LEGEND_ALGEBRAIC(:,180) = strpad('v_P4 in component SERCA (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,110) = strpad('mu_P5 in component SERCA (J_per_mol)');
    LEGEND_ALGEBRAIC(:,181) = strpad('v_P5 in component SERCA (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,114) = strpad('mu_P6 in component SERCA (J_per_mol)');
    LEGEND_ALGEBRAIC(:,185) = strpad('v_P6 in component SERCA (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,116) = strpad('mu_P8 in component SERCA (J_per_mol)');
    LEGEND_ALGEBRAIC(:,188) = strpad('v_P8 in component SERCA (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,118) = strpad('mu_P9 in component SERCA (J_per_mol)');
    LEGEND_ALGEBRAIC(:,192) = strpad('v_P9 in component SERCA (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,112) = strpad('mu_P10 in component SERCA (J_per_mol)');
    LEGEND_ALGEBRAIC(:,193) = strpad('v_P10 in component SERCA (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,124) = strpad('Af_R1_2 in component SERCA (J_per_mol)');
    LEGEND_ALGEBRAIC(:,126) = strpad('Ar_R1_2 in component SERCA (J_per_mol)');
    LEGEND_ALGEBRAIC(:,162) = strpad('v_SERCA_R1_2 in component SERCA (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,128) = strpad('Af_R5_6 in component SERCA (J_per_mol)');
    LEGEND_ALGEBRAIC(:,130) = strpad('Ar_R5_6 in component SERCA (J_per_mol)');
    LEGEND_ALGEBRAIC(:,167) = strpad('v_SERCA_R5_6 in component SERCA (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,132) = strpad('Af_R2_2a in component SERCA (J_per_mol)');
    LEGEND_ALGEBRAIC(:,134) = strpad('Ar_R2_2a in component SERCA (J_per_mol)');
    LEGEND_ALGEBRAIC(:,171) = strpad('v_SERCA_R2_2a in component SERCA (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,136) = strpad('Af_R2_4 in component SERCA (J_per_mol)');
    LEGEND_ALGEBRAIC(:,138) = strpad('Ar_R2_4 in component SERCA (J_per_mol)');
    LEGEND_ALGEBRAIC(:,174) = strpad('v_SERCA_R2_4 in component SERCA (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,140) = strpad('Af_R4_5 in component SERCA (J_per_mol)');
    LEGEND_ALGEBRAIC(:,142) = strpad('Ar_R4_5 in component SERCA (J_per_mol)');
    LEGEND_ALGEBRAIC(:,178) = strpad('v_SERCA_R4_5 in component SERCA (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,144) = strpad('Af_R6_8 in component SERCA (J_per_mol)');
    LEGEND_ALGEBRAIC(:,147) = strpad('Ar_R6_8 in component SERCA (J_per_mol)');
    LEGEND_ALGEBRAIC(:,182) = strpad('v_SERCA_R6_8 in component SERCA (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,151) = strpad('Af_R8_9 in component SERCA (J_per_mol)');
    LEGEND_ALGEBRAIC(:,153) = strpad('Ar_R8_9 in component SERCA (J_per_mol)');
    LEGEND_ALGEBRAIC(:,186) = strpad('v_SERCA_R8_9 in component SERCA (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,155) = strpad('Af_R9_10 in component SERCA (J_per_mol)');
    LEGEND_ALGEBRAIC(:,157) = strpad('Ar_R9_10 in component SERCA (J_per_mol)');
    LEGEND_ALGEBRAIC(:,189) = strpad('v_SERCA_R9_10 in component SERCA (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,120) = strpad('Af_R10_1 in component SERCA (J_per_mol)');
    LEGEND_ALGEBRAIC(:,122) = strpad('Ar_R10_1 in component SERCA (J_per_mol)');
    LEGEND_ALGEBRAIC(:,159) = strpad('v_SERCA_R10_1 in component SERCA (fmol_per_sec)');
    LEGEND_RATES(:,1) = strpad('d/dt q_membrane in component environment (fC)');
    LEGEND_RATES(:,3) = strpad('d/dt q_Cai in component crossbridge_TRPN (fmol)');
    LEGEND_RATES(:,2) = strpad('d/dt q_TRPN in component crossbridge_TRPN (fmol)');
    LEGEND_RATES(:,4) = strpad('d/dt q_Ca_TRPN in component crossbridge_TRPN (fmol)');
    LEGEND_RATES(:,5) = strpad('d/dt q_B in component crossbridge_TRPN (fmol)');
    LEGEND_RATES(:,6) = strpad('d/dt q_U in component crossbridge_TRPN (fmol)');
    LEGEND_RATES(:,7) = strpad('d/dt q_W in component crossbridge_TRPN (fmol)');
    LEGEND_RATES(:,8) = strpad('d/dt q_S in component crossbridge_TRPN (fmol)');
    LEGEND_RATES(:,30) = strpad('d/dt G_w in component crossbridge_TRPN (metre)');
    LEGEND_RATES(:,9) = strpad('d/dt SL in component crossbridge_TRPN (metre)');
    LEGEND_RATES(:,31) = strpad('d/dt G_s in component crossbridge_TRPN (metre)');
    LEGEND_RATES(:,32) = strpad('d/dt Cdd in component crossbridge_TRPN (metre)');
    LEGEND_RATES(:,10) = strpad('d/dt q_Cai in component LCC (fmol)');
    LEGEND_RATES(:,11) = strpad('d/dt q_Cao in component LCC (fmol)');
    LEGEND_RATES(:,12) = strpad('d/dt q_Ki in component LCC (fmol)');
    LEGEND_RATES(:,13) = strpad('d/dt q_Ko in component LCC (fmol)');
    LEGEND_RATES(:,33) = strpad('d/dt q_S000 in component LCC_gate (fmol)');
    LEGEND_RATES(:,39) = strpad('d/dt q_S001 in component LCC_gate (fmol)');
    LEGEND_RATES(:,34) = strpad('d/dt q_S010 in component LCC_gate (fmol)');
    LEGEND_RATES(:,40) = strpad('d/dt q_S011 in component LCC_gate (fmol)');
    LEGEND_RATES(:,35) = strpad('d/dt q_S020 in component LCC_gate (fmol)');
    LEGEND_RATES(:,41) = strpad('d/dt q_S021 in component LCC_gate (fmol)');
    LEGEND_RATES(:,36) = strpad('d/dt q_S100 in component LCC_gate (fmol)');
    LEGEND_RATES(:,42) = strpad('d/dt q_S101 in component LCC_gate (fmol)');
    LEGEND_RATES(:,37) = strpad('d/dt q_S110 in component LCC_gate (fmol)');
    LEGEND_RATES(:,43) = strpad('d/dt q_S111 in component LCC_gate (fmol)');
    LEGEND_RATES(:,38) = strpad('d/dt q_S120 in component LCC_gate (fmol)');
    LEGEND_RATES(:,44) = strpad('d/dt q_S121 in component LCC_gate (fmol)');
    LEGEND_RATES(:,14) = strpad('d/dt q_PLB in component PLB (fmol)');
    LEGEND_RATES(:,15) = strpad('d/dt q_PKACI in component PLB (fmol)');
    LEGEND_RATES(:,16) = strpad('d/dt q_PLB_PKACI in component PLB (fmol)');
    LEGEND_RATES(:,17) = strpad('d/dt q_PP1 in component PLB (fmol)');
    LEGEND_RATES(:,18) = strpad('d/dt q_PLBp_PP1 in component PLB (fmol)');
    LEGEND_RATES(:,19) = strpad('d/dt q_PLBp in component PLB (fmol)');
    LEGEND_RATES(:,20) = strpad('d/dt q_Ip in component PLB (fmol)');
    LEGEND_RATES(:,21) = strpad('d/dt q_Ip_PP1 in component PLB (fmol)');
    LEGEND_RATES(:,22) = strpad('d/dt q_Ca_SR in component RyR (fmol)');
    LEGEND_RATES(:,23) = strpad('d/dt q_Cai in component RyR (fmol)');
    LEGEND_RATES(:,48) = strpad('d/dt q_O_RyR in component RyR_gate (fmol)');
    LEGEND_RATES(:,45) = strpad('d/dt q_C_RyR in component RyR_gate (fmol)');
    LEGEND_RATES(:,46) = strpad('d/dt q_CI_RyR in component RyR_gate (fmol)');
    LEGEND_RATES(:,47) = strpad('d/dt q_I_RyR in component RyR_gate (fmol)');
    LEGEND_RATES(:,25) = strpad('d/dt q_Cai in component SERCA (fmol)');
    LEGEND_RATES(:,26) = strpad('d/dt q_Ca_SR in component SERCA (fmol)');
    LEGEND_RATES(:,24) = strpad('d/dt q_H in component SERCA (fmol)');
    LEGEND_RATES(:,28) = strpad('d/dt q_MgADP in component SERCA (fmol)');
    LEGEND_RATES(:,27) = strpad('d/dt q_MgATP in component SERCA (fmol)');
    LEGEND_RATES(:,29) = strpad('d/dt q_P in component SERCA (fmol)');
    LEGEND_RATES(:,49) = strpad('d/dt q_P1_SERCA in component SERCA (fmol)');
    LEGEND_RATES(:,50) = strpad('d/dt q_P2_SERCA in component SERCA (fmol)');
    LEGEND_RATES(:,51) = strpad('d/dt q_P2a_SERCA in component SERCA (fmol)');
    LEGEND_RATES(:,52) = strpad('d/dt q_P4_SERCA in component SERCA (fmol)');
    LEGEND_RATES(:,53) = strpad('d/dt q_P5_SERCA in component SERCA (fmol)');
    LEGEND_RATES(:,54) = strpad('d/dt q_P10_SERCA in component SERCA (fmol)');
    LEGEND_RATES(:,55) = strpad('d/dt q_P6_SERCA in component SERCA (fmol)');
    LEGEND_RATES(:,56) = strpad('d/dt q_P8_SERCA in component SERCA (fmol)');
    LEGEND_RATES(:,57) = strpad('d/dt q_P9_SERCA in component SERCA (fmol)');
    LEGEND_STATES  = LEGEND_STATES';
    LEGEND_ALGEBRAIC = LEGEND_ALGEBRAIC';
    LEGEND_RATES = LEGEND_RATES';
    LEGEND_CONSTANTS = LEGEND_CONSTANTS';
end

function [STATES, CONSTANTS] = initConsts()
    VOI = 0; CONSTANTS = []; STATES = []; ALGEBRAIC = [];
    CONSTANTS(:,1) = 114.037;
    CONSTANTS(:,2) = 6.18867;
    CONSTANTS(:,3) = 0.298505;
    CONSTANTS(:,4) = 0.00702365;
    CONSTANTS(:,5) = 126426;
    CONSTANTS(:,6) = 8.20611;
    CONSTANTS(:,7) = 15.3452;
    CONSTANTS(:,8) = 0.0925573;
    CONSTANTS(:,9) = 0.17308;
    CONSTANTS(:,10) = 956.69;
    CONSTANTS(:,11) = 23.603;
    CONSTANTS(:,12) = 44.137;
    CONSTANTS(:,13) = 0.174044;
    CONSTANTS(:,14) = 0.00429394;
    CONSTANTS(:,15) = 0.00802955;
    CONSTANTS(:,16) = 1.76246;
    CONSTANTS(:,17) = 8.75195;
    CONSTANTS(:,18) = 0.000320633;
    CONSTANTS(:,19) = 0.00159218;
    CONSTANTS(:,20) = 3.22785;
    CONSTANTS(:,21) = 16.0287;
    CONSTANTS(:,22) = 0.000587221;
    CONSTANTS(:,23) = 0.00291599;
    CONSTANTS(:,24) = 9067.48;
    CONSTANTS(:,25) = 45026.8;
    CONSTANTS(:,26) = 1.64958;
    CONSTANTS(:,27) = 8.19142;
    CONSTANTS(:,28) = 59592.5;
    CONSTANTS(:,29) = 295921;
    CONSTANTS(:,30) = 1470.24;
    CONSTANTS(:,31) = 7300.85;
    CONSTANTS(:,32) = 2749.31;
    CONSTANTS(:,33) = 13652.4;
    CONSTANTS(:,34) = 45.5263;
    CONSTANTS(:,35) = 6.55904;
    CONSTANTS(:,36) = 0.386674;
    CONSTANTS(:,37) = 1.21269;
    CONSTANTS(:,38) = 431.435;
    CONSTANTS(:,39) = 3.53995e+06;
    CONSTANTS(:,40) = 8.83262;
    CONSTANTS(:,41) = 0.12618;
    CONSTANTS(:,42) = 883.262;
    CONSTANTS(:,43) = 73.6052;
    CONSTANTS(:,44) = 2.27229e-05;
    CONSTANTS(:,45) = 106884;
    CONSTANTS(:,46) = 2.78115e+06;
    CONSTANTS(:,47) = 106884;
    CONSTANTS(:,48) = 3440.8;
    CONSTANTS(:,49) = 3.04364e+06;
    CONSTANTS(:,50) = 1.03099e+07;
    CONSTANTS(:,51) = 1.03099e+07;
    CONSTANTS(:,52) = 0.00568924;
    CONSTANTS(:,53) = 14.0366;
    CONSTANTS(:,54) = 0.0527926;
    CONSTANTS(:,55) = 0.0509829;
    CONSTANTS(:,56) = 6.75199;
    CONSTANTS(:,57) = 2.532;
    CONSTANTS(:,58) = 16.5554;
    CONSTANTS(:,59) = 4.13884e-06;
    CONSTANTS(:,60) = 0.0527926;
    CONSTANTS(:,61) = 0.00367934;
    CONSTANTS(:,62) = 0.00367934;
    CONSTANTS(:,63) = 0.0147906;
    CONSTANTS(:,64) = 0.599501;
    CONSTANTS(:,65) = 0.320594;
    CONSTANTS(:,66) = 0.00297853;
    CONSTANTS(:,67) = 0.120727;
    CONSTANTS(:,68) = 0.064561;
    CONSTANTS(:,69) = 81.3015;
    CONSTANTS(:,70) = 3295.35;
    CONSTANTS(:,71) = 1762.25;
    CONSTANTS(:,72) = 16.3725;
    CONSTANTS(:,73) = 663.616;
    CONSTANTS(:,74) = 354.881;
    CONSTANTS(:,75) = 0.00235741;
    CONSTANTS(:,76) = 0.395191;
    CONSTANTS(:,77) = 0.638527;
    CONSTANTS(:,78) = 0.361989;
    CONSTANTS(:,79) = 0.203757;
    CONSTANTS(:,80) = 0.326014;
    CONSTANTS(:,81) = 5.41093;
    CONSTANTS(:,82) = 0.0673793;
    CONSTANTS(:,83) = 0.0527926;
    CONSTANTS(:,84) = 115.191;
    CONSTANTS(:,85) = 1.15191;
    CONSTANTS(:,86) = 0.00197471;
    CONSTANTS(:,87) = 0.197471;
    CONSTANTS(:,88) = 901.774;
    CONSTANTS(:,89) = 2579.2;
    CONSTANTS(:,90) = 270.718;
    CONSTANTS(:,91) = 7044.18;
    CONSTANTS(:,92) = 0.0214593;
    CONSTANTS(:,93) = 1241.21;
    CONSTANTS(:,94) = 75.0041;
    CONSTANTS(:,95) = 73.0274;
    CONSTANTS(:,96) = 104.747;
    CONSTANTS(:,97) = 279.929;
    CONSTANTS(:,98) = 1068.12;
    CONSTANTS(:,99) = 1.32969e-05;
    CONSTANTS(:,100) = 0.0245424;
    CONSTANTS(:,101) = 34.4;
    CONSTANTS(:,102) = 500;
    CONSTANTS(:,103) = 1.381e5;
    CONSTANTS(:,104) = 96485;
    STATES(:,1) = -13039;
    CONSTANTS(:,105) = 2.57;
    CONSTANTS(:,106) = 1e-18;
    CONSTANTS(:,107) = 6.82e-3;
    CONSTANTS(:,108) = 1;
    CONSTANTS(:,109) = 0;
    CONSTANTS(:,110) = 0;
    CONSTANTS(:,111) = 0;
    CONSTANTS(:,112) = 6.84;
    CONSTANTS(:,113) = 5.51E+03;
    CONSTANTS(:,114) = 2.05E+02;
    CONSTANTS(:,115) = 4.028E+00;
    CONSTANTS(:,116) = 2.234E-03;
    CONSTANTS(:,117) = 1e-18;
    CONSTANTS(:,118) = 3.382E-02;
    CONSTANTS(:,119) = 1e-18;
    CONSTANTS(:,120) = 1e-18;
    CONSTANTS(:,121) = 1.999E-03;
    CONSTANTS(:,122) = 1e-18;
    CONSTANTS(:,123) = 0.641;
    CONSTANTS(:,124) = 0.004028;
    CONSTANTS(:,125) = 570;
    CONSTANTS(:,126) = 1.3794;
    CONSTANTS(:,127) = 3.8;
    STATES(:,2) = 1e-16;
    STATES(:,3) = 1e-16;
    STATES(:,4) = 1e-16;
    STATES(:,5) = 1e-16;
    STATES(:,6) = 1e-16;
    STATES(:,7) = 1e-16;
    STATES(:,8) = 1e-16;
    STATES(:,9) = 1e-6;
    STATES(:,10) = 1e-16;
    STATES(:,11) = 1e-16;
    STATES(:,12) = 1e-16;
    STATES(:,13) = 1e-16;
    STATES(:,14) = 1e-16;
    STATES(:,15) = 1e-16;
    STATES(:,16) = 1e-16;
    STATES(:,17) = 1e-16;
    STATES(:,18) = 1e-16;
    STATES(:,19) = 1e-16;
    STATES(:,20) = 1e-16;
    STATES(:,21) = 1e-16;
    STATES(:,22) = 1e-16;
    STATES(:,23) = 1e-16;
    STATES(:,24) = 1e-16;
    STATES(:,25) = 1e-16;
    STATES(:,26) = 1e-16;
    STATES(:,27) = 1e-16;
    STATES(:,28) = 1e-16;
    STATES(:,29) = 1e-16;
    CONSTANTS(:,128) = 4e-2;
    CONSTANTS(:,129) = 4.1e-2;
    CONSTANTS(:,130) = 1e8;
    CONSTANTS(:,131) = 0;
    CONSTANTS(:,132) = 2;
    CONSTANTS(:,133) = 1;
    CONSTANTS(:,134) = 8.31;
    CONSTANTS(:,135) = 310;
    CONSTANTS(:,136) = 1;
    CONSTANTS(:,137) = -1;
    CONSTANTS(:,138) = 1.1;
    CONSTANTS(:,139) = -0.0118;
    CONSTANTS(:,140) = 1;
    CONSTANTS(:,141) = 2e-6;
    CONSTANTS(:,142) = 1e-6;
    CONSTANTS(:,143) = 0.25;
    CONSTANTS(:,144) = 0.5;
    CONSTANTS(:,145) = 25;
    CONSTANTS(:,146) = 2.23;
    CONSTANTS(:,147) = 26;
    CONSTANTS(:,148) = 4;
    STATES(:,30) = 1e-6;
    STATES(:,31) = 1e-6;
    CONSTANTS(:,149) = 0;
    CONSTANTS(:,150) = 1;
    CONSTANTS(:,151) = 40.5;
    STATES(:,32) = 0;
    CONSTANTS(:,152) = 200e3;
    CONSTANTS(:,153) = 200e3;
    CONSTANTS(:,154) = 7;
    CONSTANTS(:,155) = 2.1;
    STATES(:,33) = 3.6989e-07;
    STATES(:,34) = 7.3239e-05;
    STATES(:,35) = 3.6989e-07;
    STATES(:,36) = 3.7363e-09;
    STATES(:,37) = 7.3979e-07;
    STATES(:,38) = 3.7363e-09;
    STATES(:,39) = 4.1099e-08;
    STATES(:,40) = 8.1377e-06;
    STATES(:,41) = 4.1099e-08;
    STATES(:,42) = 4.1514e-10;
    STATES(:,43) = 8.2199e-08;
    STATES(:,44) = 4.1514e-10;
    CONSTANTS(:,156) = 2;
    CONSTANTS(:,157) = 2.1404;
    CONSTANTS(:,158) = -1.1495;
    CONSTANTS(:,159) = 0.72162;
    CONSTANTS(:,160) = 4.2933;
    CONSTANTS(:,161) = -2.1404;
    CONSTANTS(:,162) = 1.8993;
    CONSTANTS(:,163) = -0.52288;
    CONSTANTS(:,164) = 0;
    CONSTANTS(:,165) = 1;
    CONSTANTS(:,166) = 2;
    STATES(:,45) = 0.25e-3;
    STATES(:,46) = 0.25e-3;
    STATES(:,47) = 0.25e-3;
    STATES(:,48) = 0.25e-3;
    CONSTANTS(:,167) = 2;
    CONSTANTS(:,168) = 2;
    CONSTANTS(:,169) = 2;
    STATES(:,49) = 0.11111;
    STATES(:,50) = 0.11111;
    STATES(:,51) = 0.11111;
    STATES(:,52) = 0.11111;
    STATES(:,53) = 0.11111;
    STATES(:,54) = 0.11111;
    STATES(:,55) = 0.11111;
    STATES(:,56) = 0.11111;
    STATES(:,57) = 0.11111;
    CONSTANTS(:,170) = 34.0;
    CONSTANTS(:,171) = ( CONSTANTS(:,146).*CONSTANTS(:,147).*(1.00000 - CONSTANTS(:,144)))./CONSTANTS(:,144);
    CONSTANTS(:,172) = ( CONSTANTS(:,146).*CONSTANTS(:,148).*(1.00000 - CONSTANTS(:,143)).*CONSTANTS(:,144))./CONSTANTS(:,143);
    CONSTANTS(:,173) = ( CONSTANTS(:,145).*CONSTANTS(:,143))./( (1.00000 - CONSTANTS(:,143)).*CONSTANTS(:,144)+CONSTANTS(:,143));
    CONSTANTS(:,174) =  CONSTANTS(:,139).*CONSTANTS(:,134).*CONSTANTS(:,135);
    CONSTANTS(:,175) =  CONSTANTS(:,170).*0.0350000;
%     CONSTANTS(:,180) = CONSTANTS(:,149);
    CONSTANTS(:,176) = CONSTANTS(:,173);
    CONSTANTS(:,177) =   - CONSTANTS(:,173).*CONSTANTS(:,149).*CONSTANTS(:,150);
    CONSTANTS(:,178) =  CONSTANTS(:,134).*CONSTANTS(:,135);
    CONSTANTS(:,179) = CONSTANTS(:,170)+CONSTANTS(:,175);
    CONSTANTS(:,180) =   - CONSTANTS(:,176).*CONSTANTS(:,149).*CONSTANTS(:,150);
    if (isempty(STATES)), warning('Initial values for states not set');, end
end

function [RATES, ALGEBRAIC] = computeRates(VOI, STATES, CONSTANTS)
    disp(VOI)
    global algebraicVariableCount;
    statesSize = size(STATES);
    statesColumnCount = statesSize(2);
    if ( statesColumnCount == 1)
        STATES = STATES';
        ALGEBRAIC = zeros(1, algebraicVariableCount);
        utilOnes = 1;
    else
        statesRowCount = statesSize(1);
        ALGEBRAIC = zeros(statesRowCount, algebraicVariableCount);
        RATES = zeros(statesRowCount, statesColumnCount);
        utilOnes = ones(statesRowCount, 1);
    end
    RATES(:,9) = CONSTANTS(:,149);
    ALGEBRAIC(:,2) =  CONSTANTS(:,171).*STATES(:,30).*CONSTANTS(:,150);
    ALGEBRAIC(:,12) =  - CONSTANTS(:,177) - ALGEBRAIC(:,2);
    ALGEBRAIC(:,16) = ALGEBRAIC(:,12)./CONSTANTS(:,150);
    RATES(:,30) = ALGEBRAIC(:,16);
    ALGEBRAIC(:,3) =  CONSTANTS(:,172).*STATES(:,31).*CONSTANTS(:,150);
    ALGEBRAIC(:,13) =  - CONSTANTS(:,180) - ALGEBRAIC(:,3);
    ALGEBRAIC(:,17) = ALGEBRAIC(:,13)./CONSTANTS(:,150);
    RATES(:,31) = ALGEBRAIC(:,17);
    ALGEBRAIC(:,18) = CONSTANTS(:,106)+STATES(:,4);
    ALGEBRAIC(:,49) =  CONSTANTS(:,134).*CONSTANTS(:,135).*log( CONSTANTS(:,55).*ALGEBRAIC(:,18));
    ALGEBRAIC(:,22) = CONSTANTS(:,108)+STATES(:,5);
    ALGEBRAIC(:,54) =  CONSTANTS(:,134).*CONSTANTS(:,135).*log( CONSTANTS(:,56).*ALGEBRAIC(:,22));
    ALGEBRAIC(:,25) = CONSTANTS(:,109)+STATES(:,6);
    ALGEBRAIC(:,58) =  CONSTANTS(:,134).*CONSTANTS(:,135).*log( CONSTANTS(:,57).*ALGEBRAIC(:,25));
    ALGEBRAIC(:,73) =  CONSTANTS(:,2).*(exp((ALGEBRAIC(:,54)+ CONSTANTS(:,138).*ALGEBRAIC(:,49))./( CONSTANTS(:,134).*CONSTANTS(:,135))) - exp((ALGEBRAIC(:,58)+ CONSTANTS(:,138).*ALGEBRAIC(:,49))./( CONSTANTS(:,134).*CONSTANTS(:,135))));
    RATES(:,5) =  - ALGEBRAIC(:,73);
    [CONSTANTS, STATES, ALGEBRAIC] = rootfind_0(VOI, CONSTANTS, STATES, ALGEBRAIC);
    ALGEBRAIC(:,81) = ALGEBRAIC(:,75)./CONSTANTS(:,150);
    RATES(:,32) = ALGEBRAIC(:,81);
    ALGEBRAIC(:,29) = CONSTANTS(:,110)+STATES(:,7);
    ALGEBRAIC(:,63) =  CONSTANTS(:,134).*CONSTANTS(:,135).*log( CONSTANTS(:,58).*ALGEBRAIC(:,29));
    ALGEBRAIC(:,82) =  CONSTANTS(:,3).*(exp(ALGEBRAIC(:,58)./( CONSTANTS(:,134).*CONSTANTS(:,135))) - exp(ALGEBRAIC(:,63)./( CONSTANTS(:,134).*CONSTANTS(:,135))));
    ALGEBRAIC(:,34) = CONSTANTS(:,111)+STATES(:,8);
    ALGEBRAIC(:,68) =  CONSTANTS(:,134).*CONSTANTS(:,135).*log( CONSTANTS(:,59).*ALGEBRAIC(:,34));
    ALGEBRAIC(:,87) =  CONSTANTS(:,4).*(exp(ALGEBRAIC(:,63)./( CONSTANTS(:,134).*CONSTANTS(:,135))) - exp(ALGEBRAIC(:,68)./( CONSTANTS(:,134).*CONSTANTS(:,135))));
    RATES(:,7) = ALGEBRAIC(:,82) - ALGEBRAIC(:,87);
    ALGEBRAIC(:,92) =  CONSTANTS(:,5).*(exp(ALGEBRAIC(:,68)./( CONSTANTS(:,134).*CONSTANTS(:,135))) - exp(ALGEBRAIC(:,58)./( CONSTANTS(:,134).*CONSTANTS(:,135))));
    RATES(:,6) = (ALGEBRAIC(:,73) - ALGEBRAIC(:,82))+ALGEBRAIC(:,92);
    RATES(:,8) = ALGEBRAIC(:,87) - ALGEBRAIC(:,92);
    ALGEBRAIC(:,1) = CONSTANTS(:,115)+STATES(:,14);
    ALGEBRAIC(:,46) =  CONSTANTS(:,134).*CONSTANTS(:,135).*log( CONSTANTS(:,75).*ALGEBRAIC(:,1));
    ALGEBRAIC(:,11) = CONSTANTS(:,116)+STATES(:,15);
    ALGEBRAIC(:,51) =  CONSTANTS(:,134).*CONSTANTS(:,135).*log( CONSTANTS(:,76).*ALGEBRAIC(:,11));
    ALGEBRAIC(:,15) = CONSTANTS(:,117)+STATES(:,16);
    ALGEBRAIC(:,57) =  CONSTANTS(:,134).*CONSTANTS(:,135).*log( CONSTANTS(:,77).*ALGEBRAIC(:,15));
    ALGEBRAIC(:,89) =  CONSTANTS(:,34).*(exp((ALGEBRAIC(:,46)+ALGEBRAIC(:,51))./( CONSTANTS(:,134).*CONSTANTS(:,135))) - exp(ALGEBRAIC(:,57)./( CONSTANTS(:,134).*CONSTANTS(:,135))));
    ALGEBRAIC(:,26) = CONSTANTS(:,120)+STATES(:,19);
    ALGEBRAIC(:,71) =  CONSTANTS(:,134).*CONSTANTS(:,135).*log( CONSTANTS(:,80).*ALGEBRAIC(:,26));
    ALGEBRAIC(:,94) =  CONSTANTS(:,35).*(exp(ALGEBRAIC(:,57)./( CONSTANTS(:,134).*CONSTANTS(:,135))) - exp((ALGEBRAIC(:,71)+ALGEBRAIC(:,51))./( CONSTANTS(:,134).*CONSTANTS(:,135))));
    RATES(:,15) = ALGEBRAIC(:,94) - ALGEBRAIC(:,89);
    RATES(:,16) = ALGEBRAIC(:,89) - ALGEBRAIC(:,94);
    ALGEBRAIC(:,19) = CONSTANTS(:,118)+STATES(:,17);
    ALGEBRAIC(:,61) =  CONSTANTS(:,134).*CONSTANTS(:,135).*log( CONSTANTS(:,78).*ALGEBRAIC(:,19));
    ALGEBRAIC(:,23) = CONSTANTS(:,119)+STATES(:,18);
    ALGEBRAIC(:,66) =  CONSTANTS(:,134).*CONSTANTS(:,135).*log( CONSTANTS(:,79).*ALGEBRAIC(:,23));
    ALGEBRAIC(:,98) =  CONSTANTS(:,36).*(exp((ALGEBRAIC(:,71)+ALGEBRAIC(:,61))./( CONSTANTS(:,134).*CONSTANTS(:,135))) - exp(ALGEBRAIC(:,66)./( CONSTANTS(:,134).*CONSTANTS(:,135))));
    RATES(:,19) = ALGEBRAIC(:,94) - ALGEBRAIC(:,98);
    ALGEBRAIC(:,102) =  CONSTANTS(:,37).*(exp(ALGEBRAIC(:,66)./( CONSTANTS(:,134).*CONSTANTS(:,135))) - exp((ALGEBRAIC(:,46)+ALGEBRAIC(:,61))./( CONSTANTS(:,134).*CONSTANTS(:,135))));
    RATES(:,14) = ALGEBRAIC(:,102) - ALGEBRAIC(:,89);
    RATES(:,18) = ALGEBRAIC(:,98) - ALGEBRAIC(:,102);
    ALGEBRAIC(:,30) = CONSTANTS(:,121)+STATES(:,20);
    ALGEBRAIC(:,79) =  CONSTANTS(:,134).*CONSTANTS(:,135).*log( CONSTANTS(:,81).*ALGEBRAIC(:,30));
    ALGEBRAIC(:,35) = CONSTANTS(:,122)+STATES(:,21);
    ALGEBRAIC(:,84) =  CONSTANTS(:,134).*CONSTANTS(:,135).*log( CONSTANTS(:,82).*ALGEBRAIC(:,35));
    ALGEBRAIC(:,106) =  CONSTANTS(:,38).*(exp((ALGEBRAIC(:,61)+ALGEBRAIC(:,79))./( CONSTANTS(:,134).*CONSTANTS(:,135))) - exp(ALGEBRAIC(:,84)./( CONSTANTS(:,134).*CONSTANTS(:,135))));
    RATES(:,17) = (ALGEBRAIC(:,102) - ALGEBRAIC(:,98)) - ALGEBRAIC(:,106);
    RATES(:,20) =  - ALGEBRAIC(:,106);
    RATES(:,21) = ALGEBRAIC(:,106);
    ALGEBRAIC(:,4) = CONSTANTS(:,105)+STATES(:,2);
    ALGEBRAIC(:,38) =  CONSTANTS(:,134).*CONSTANTS(:,135).*log( CONSTANTS(:,53).*ALGEBRAIC(:,4));
    ALGEBRAIC(:,14) = CONSTANTS(:,107)+STATES(:,3)+STATES(:,10)+STATES(:,23)+STATES(:,25);
    ALGEBRAIC(:,43) =  CONSTANTS(:,134).*CONSTANTS(:,135).*log( CONSTANTS(:,54).*ALGEBRAIC(:,14));
    ALGEBRAIC(:,55) =  (CONSTANTS(:,151)./( CONSTANTS(:,141).*CONSTANTS(:,142).*CONSTANTS(:,143))).*STATES(:,8).*(STATES(:,31)+CONSTANTS(:,141));
    ALGEBRAIC(:,59) =  (CONSTANTS(:,151)./( CONSTANTS(:,141).*CONSTANTS(:,142).*CONSTANTS(:,143))).*STATES(:,7).*STATES(:,30);
    ALGEBRAIC(:,64) = ALGEBRAIC(:,55)+ALGEBRAIC(:,59);
    ALGEBRAIC(:,69) = ALGEBRAIC(:,64);
    ALGEBRAIC(:,86) =  (( CONSTANTS(:,155).*ALGEBRAIC(:,74))./CONSTANTS(:,141)).*ALGEBRAIC(:,81);
    ALGEBRAIC(:,91) = ALGEBRAIC(:,86);
    ALGEBRAIC(:,96) = ALGEBRAIC(:,69)+ALGEBRAIC(:,91);
    ALGEBRAIC(:,100) =  ALGEBRAIC(:,96).*1000.00;
    ALGEBRAIC(:,104) =  CONSTANTS(:,140).*CONSTANTS(:,174).*ALGEBRAIC(:,100);
    ALGEBRAIC(:,108) =  CONSTANTS(:,1).*(exp((ALGEBRAIC(:,43)+ALGEBRAIC(:,38))./( CONSTANTS(:,134).*CONSTANTS(:,135))) - exp((ALGEBRAIC(:,49)+ALGEBRAIC(:,104))./( CONSTANTS(:,134).*CONSTANTS(:,135))));
    RATES(:,3) =  - ALGEBRAIC(:,108);
    RATES(:,2) =  - ALGEBRAIC(:,108);
    RATES(:,4) = ALGEBRAIC(:,108);
    ALGEBRAIC(:,50) = STATES(:,1)./CONSTANTS(:,103);
    ALGEBRAIC(:,78) =  CONSTANTS(:,132).*CONSTANTS(:,104).*ALGEBRAIC(:,50);
    ALGEBRAIC(:,56) =  CONSTANTS(:,178).*log( CONSTANTS(:,54).*ALGEBRAIC(:,14));
    ALGEBRAIC(:,117) =  CONSTANTS(:,178).*log( CONSTANTS(:,73).*STATES(:,43));
    ALGEBRAIC(:,119) = ALGEBRAIC(:,56)+ALGEBRAIC(:,78)+ALGEBRAIC(:,117);
    ALGEBRAIC(:,20) = CONSTANTS(:,112)+STATES(:,11);
    ALGEBRAIC(:,60) =  CONSTANTS(:,178).*log( CONSTANTS(:,60).*ALGEBRAIC(:,20));
    ALGEBRAIC(:,121) = ALGEBRAIC(:,60)+ALGEBRAIC(:,117);
    ALGEBRAIC(:,127) = piecewise({ALGEBRAIC(:,78)==0.000000,  CONSTANTS(:,6).*(exp(ALGEBRAIC(:,119)./CONSTANTS(:,178)) - exp(ALGEBRAIC(:,121)./CONSTANTS(:,178))) },  ((( CONSTANTS(:,6).*ALGEBRAIC(:,78))./CONSTANTS(:,178))./(exp(ALGEBRAIC(:,78)./CONSTANTS(:,178)) - 1.00000)).*(exp(ALGEBRAIC(:,119)./CONSTANTS(:,178)) - exp(ALGEBRAIC(:,121)./CONSTANTS(:,178))));
    ALGEBRAIC(:,133) =  CONSTANTS(:,178).*log( CONSTANTS(:,74).*STATES(:,44));
    ALGEBRAIC(:,135) = ALGEBRAIC(:,56)+ALGEBRAIC(:,78)+ALGEBRAIC(:,133);
    ALGEBRAIC(:,137) = ALGEBRAIC(:,60)+ALGEBRAIC(:,133);
    ALGEBRAIC(:,143) = piecewise({ALGEBRAIC(:,78)==0.000000,  CONSTANTS(:,7).*(exp(ALGEBRAIC(:,135)./CONSTANTS(:,178)) - exp(ALGEBRAIC(:,137)./CONSTANTS(:,178))) },  ((( CONSTANTS(:,7).*ALGEBRAIC(:,78))./CONSTANTS(:,178))./(exp(ALGEBRAIC(:,78)./CONSTANTS(:,178)) - 1.00000)).*(exp(ALGEBRAIC(:,135)./CONSTANTS(:,178)) - exp(ALGEBRAIC(:,137)./CONSTANTS(:,178))));
    ALGEBRAIC(:,145) = ALGEBRAIC(:,143)+ALGEBRAIC(:,127);
    RATES(:,11) = ALGEBRAIC(:,145);
    ALGEBRAIC(:,83) =  CONSTANTS(:,133).*CONSTANTS(:,104).*ALGEBRAIC(:,50);
    ALGEBRAIC(:,24) = CONSTANTS(:,113)+STATES(:,12);
    ALGEBRAIC(:,65) =  CONSTANTS(:,178).*log( CONSTANTS(:,61).*ALGEBRAIC(:,24));
    ALGEBRAIC(:,123) = ALGEBRAIC(:,65)+ALGEBRAIC(:,83)+ALGEBRAIC(:,117);
    ALGEBRAIC(:,27) = CONSTANTS(:,114)+STATES(:,13);
    ALGEBRAIC(:,70) =  CONSTANTS(:,178).*log( CONSTANTS(:,62).*ALGEBRAIC(:,27));
    ALGEBRAIC(:,125) = ALGEBRAIC(:,70)+ALGEBRAIC(:,117);
    ALGEBRAIC(:,129) = piecewise({ALGEBRAIC(:,83)==0.000000,  CONSTANTS(:,8).*(exp(ALGEBRAIC(:,123)./CONSTANTS(:,178)) - exp(ALGEBRAIC(:,125)./CONSTANTS(:,178))) },  ((( CONSTANTS(:,8).*ALGEBRAIC(:,83))./CONSTANTS(:,178))./(exp(ALGEBRAIC(:,83)./CONSTANTS(:,178)) - 1.00000)).*(exp(ALGEBRAIC(:,123)./CONSTANTS(:,178)) - exp(ALGEBRAIC(:,125)./CONSTANTS(:,178))));
    ALGEBRAIC(:,139) = ALGEBRAIC(:,65)+ALGEBRAIC(:,83)+ALGEBRAIC(:,133);
    ALGEBRAIC(:,141) = ALGEBRAIC(:,70)+ALGEBRAIC(:,133);
    ALGEBRAIC(:,146) = piecewise({ALGEBRAIC(:,83)==0.000000,  CONSTANTS(:,9).*(exp(ALGEBRAIC(:,139)./CONSTANTS(:,178)) - exp(ALGEBRAIC(:,141)./CONSTANTS(:,178))) },  ((( CONSTANTS(:,9).*ALGEBRAIC(:,83))./CONSTANTS(:,178))./(exp(ALGEBRAIC(:,83)./CONSTANTS(:,178)) - 1.00000)).*(exp(ALGEBRAIC(:,139)./CONSTANTS(:,178)) - exp(ALGEBRAIC(:,141)./CONSTANTS(:,178))));
    ALGEBRAIC(:,148) =  - ALGEBRAIC(:,129) - ALGEBRAIC(:,146);
    RATES(:,12) = ALGEBRAIC(:,148);
    ALGEBRAIC(:,149) = ALGEBRAIC(:,146)+ALGEBRAIC(:,129);
    RATES(:,13) = ALGEBRAIC(:,149);
    ALGEBRAIC(:,112) =  CONSTANTS(:,134).*CONSTANTS(:,135).*log( CONSTANTS(:,96).*STATES(:,54));
    ALGEBRAIC(:,120) = ALGEBRAIC(:,112);
    ALGEBRAIC(:,95) =  CONSTANTS(:,134).*CONSTANTS(:,135).*log( CONSTANTS(:,88).*STATES(:,49));
    ALGEBRAIC(:,52) = CONSTANTS(:,125)+STATES(:,29);
    ALGEBRAIC(:,90) =  CONSTANTS(:,134).*CONSTANTS(:,135).*log( CONSTANTS(:,100).*ALGEBRAIC(:,52));
    ALGEBRAIC(:,122) = ALGEBRAIC(:,95)+ALGEBRAIC(:,90);
    ALGEBRAIC(:,159) =  CONSTANTS(:,52).*(exp(ALGEBRAIC(:,120)./( CONSTANTS(:,134).*CONSTANTS(:,135))) - exp(ALGEBRAIC(:,122)./( CONSTANTS(:,134).*CONSTANTS(:,135))));
    ALGEBRAIC(:,161) = ALGEBRAIC(:,159);
    RATES(:,29) = ALGEBRAIC(:,161);
    ALGEBRAIC(:,40) = CONSTANTS(:,127)+STATES(:,27);
    ALGEBRAIC(:,85) =  CONSTANTS(:,134).*CONSTANTS(:,135).*log( CONSTANTS(:,98).*ALGEBRAIC(:,40));
    ALGEBRAIC(:,124) = ALGEBRAIC(:,95)+ALGEBRAIC(:,85);
    ALGEBRAIC(:,99) =  CONSTANTS(:,134).*CONSTANTS(:,135).*log( CONSTANTS(:,89).*STATES(:,50));
    ALGEBRAIC(:,126) = ALGEBRAIC(:,99);
    ALGEBRAIC(:,162) =  CONSTANTS(:,44).*(exp(ALGEBRAIC(:,124)./( CONSTANTS(:,134).*CONSTANTS(:,135))) - exp(ALGEBRAIC(:,126)./( CONSTANTS(:,134).*CONSTANTS(:,135))));
    ALGEBRAIC(:,165) =  - ALGEBRAIC(:,162);
    RATES(:,27) = ALGEBRAIC(:,165);
    ALGEBRAIC(:,166) = ALGEBRAIC(:,159) - ALGEBRAIC(:,162);
    RATES(:,49) = ALGEBRAIC(:,166);
    ALGEBRAIC(:,88) =  CONSTANTS(:,178).*log( CONSTANTS(:,63).*STATES(:,33));
    ALGEBRAIC(:,93) =  CONSTANTS(:,178).*log( CONSTANTS(:,69).*STATES(:,39));
    ALGEBRAIC(:,150) =  CONSTANTS(:,28).*(exp(ALGEBRAIC(:,88)./CONSTANTS(:,178)) - exp((ALGEBRAIC(:,93)+ CONSTANTS(:,156).*ALGEBRAIC(:,56))./CONSTANTS(:,178)));
    ALGEBRAIC(:,97) =  CONSTANTS(:,178).*log( CONSTANTS(:,64).*STATES(:,34));
    ALGEBRAIC(:,101) =  CONSTANTS(:,178).*log( CONSTANTS(:,70).*STATES(:,40));
    ALGEBRAIC(:,152) =  CONSTANTS(:,30).*(exp(ALGEBRAIC(:,97)./CONSTANTS(:,178)) - exp((ALGEBRAIC(:,101)+ CONSTANTS(:,156).*ALGEBRAIC(:,56))./CONSTANTS(:,178)));
    ALGEBRAIC(:,105) =  CONSTANTS(:,178).*log( CONSTANTS(:,65).*STATES(:,35));
    ALGEBRAIC(:,109) =  CONSTANTS(:,178).*log( CONSTANTS(:,71).*STATES(:,41));
    ALGEBRAIC(:,154) =  CONSTANTS(:,32).*(exp(ALGEBRAIC(:,105)./CONSTANTS(:,178)) - exp((ALGEBRAIC(:,109)+ CONSTANTS(:,156).*ALGEBRAIC(:,56))./CONSTANTS(:,178)));
    ALGEBRAIC(:,111) =  CONSTANTS(:,178).*log( CONSTANTS(:,66).*STATES(:,36));
    ALGEBRAIC(:,113) =  CONSTANTS(:,178).*log( CONSTANTS(:,72).*STATES(:,42));
    ALGEBRAIC(:,156) =  CONSTANTS(:,29).*(exp(ALGEBRAIC(:,111)./CONSTANTS(:,178)) - exp((ALGEBRAIC(:,113)+ CONSTANTS(:,156).*ALGEBRAIC(:,56))./CONSTANTS(:,178)));
    ALGEBRAIC(:,115) =  CONSTANTS(:,178).*log( CONSTANTS(:,67).*STATES(:,37));
    ALGEBRAIC(:,158) =  CONSTANTS(:,31).*(exp(ALGEBRAIC(:,115)./CONSTANTS(:,178)) - exp((ALGEBRAIC(:,117)+ CONSTANTS(:,156).*ALGEBRAIC(:,56))./CONSTANTS(:,178)));
    ALGEBRAIC(:,131) =  CONSTANTS(:,178).*log( CONSTANTS(:,68).*STATES(:,38));
    ALGEBRAIC(:,160) =  CONSTANTS(:,33).*(exp(ALGEBRAIC(:,131)./CONSTANTS(:,178)) - exp((ALGEBRAIC(:,133)+ CONSTANTS(:,156).*ALGEBRAIC(:,56))./CONSTANTS(:,178)));
    ALGEBRAIC(:,163) =  CONSTANTS(:,132).*(ALGEBRAIC(:,156)+ALGEBRAIC(:,158)+ALGEBRAIC(:,154)+ALGEBRAIC(:,152)+ALGEBRAIC(:,150)+ALGEBRAIC(:,160));
    ALGEBRAIC(:,168) = (ALGEBRAIC(:,163) - ALGEBRAIC(:,127)) - ALGEBRAIC(:,143);
    RATES(:,10) = ALGEBRAIC(:,168);
    ALGEBRAIC(:,110) =  CONSTANTS(:,134).*CONSTANTS(:,135).*log( CONSTANTS(:,92).*STATES(:,53));
    ALGEBRAIC(:,128) = ALGEBRAIC(:,110);
    ALGEBRAIC(:,47) = CONSTANTS(:,126)+STATES(:,28);
    ALGEBRAIC(:,80) =  CONSTANTS(:,134).*CONSTANTS(:,135).*log( CONSTANTS(:,99).*ALGEBRAIC(:,47));
    ALGEBRAIC(:,114) =  CONSTANTS(:,134).*CONSTANTS(:,135).*log( CONSTANTS(:,93).*STATES(:,55));
    ALGEBRAIC(:,130) = ALGEBRAIC(:,80)+ALGEBRAIC(:,114);
    ALGEBRAIC(:,167) =  CONSTANTS(:,48).*(exp(ALGEBRAIC(:,128)./( CONSTANTS(:,134).*CONSTANTS(:,135))) - exp(ALGEBRAIC(:,130)./( CONSTANTS(:,134).*CONSTANTS(:,135))));
    ALGEBRAIC(:,170) = ALGEBRAIC(:,167);
    RATES(:,28) = ALGEBRAIC(:,170);
    ALGEBRAIC(:,36) = CONSTANTS(:,124)+STATES(:,24);
    ALGEBRAIC(:,72) =  CONSTANTS(:,134).*CONSTANTS(:,135).*log( CONSTANTS(:,97).*ALGEBRAIC(:,36));
    ALGEBRAIC(:,132) = ALGEBRAIC(:,99)+ALGEBRAIC(:,72);
    ALGEBRAIC(:,103) =  CONSTANTS(:,134).*CONSTANTS(:,135).*log( CONSTANTS(:,90).*STATES(:,51));
    ALGEBRAIC(:,134) = ALGEBRAIC(:,103);
    ALGEBRAIC(:,171) =  CONSTANTS(:,46).*(exp(ALGEBRAIC(:,132)./( CONSTANTS(:,134).*CONSTANTS(:,135))) - exp(ALGEBRAIC(:,134)./( CONSTANTS(:,134).*CONSTANTS(:,135))));
    ALGEBRAIC(:,173) = ALGEBRAIC(:,171);
    RATES(:,51) = ALGEBRAIC(:,173);
    ALGEBRAIC(:,62) =  CONSTANTS(:,134).*CONSTANTS(:,135).*log( CONSTANTS(:,54).*ALGEBRAIC(:,14));
    ALGEBRAIC(:,136) = ALGEBRAIC(:,99)+ CONSTANTS(:,167).*ALGEBRAIC(:,62);
    ALGEBRAIC(:,107) =  CONSTANTS(:,134).*CONSTANTS(:,135).*log( CONSTANTS(:,91).*STATES(:,52));
    ALGEBRAIC(:,138) = ALGEBRAIC(:,107);
    ALGEBRAIC(:,174) =  CONSTANTS(:,45).*(exp(ALGEBRAIC(:,136)./( CONSTANTS(:,134).*CONSTANTS(:,135))) - exp(ALGEBRAIC(:,138)./( CONSTANTS(:,134).*CONSTANTS(:,135))));
    ALGEBRAIC(:,176) =   - CONSTANTS(:,167).*ALGEBRAIC(:,174);
    RATES(:,25) = ALGEBRAIC(:,176);
    ALGEBRAIC(:,177) = ALGEBRAIC(:,162) - ALGEBRAIC(:,174);
    RATES(:,50) = ALGEBRAIC(:,177);
    ALGEBRAIC(:,140) = ALGEBRAIC(:,107);
    ALGEBRAIC(:,142) = ALGEBRAIC(:,110)+ CONSTANTS(:,169).*ALGEBRAIC(:,72);
    ALGEBRAIC(:,178) =  CONSTANTS(:,47).*(exp(ALGEBRAIC(:,140)./( CONSTANTS(:,134).*CONSTANTS(:,135))) - exp(ALGEBRAIC(:,142)./( CONSTANTS(:,134).*CONSTANTS(:,135))));
    ALGEBRAIC(:,180) = ALGEBRAIC(:,174) - ALGEBRAIC(:,178);
    RATES(:,52) = ALGEBRAIC(:,180);
    ALGEBRAIC(:,181) = ALGEBRAIC(:,178) - ALGEBRAIC(:,167);
    RATES(:,53) = ALGEBRAIC(:,181);
    ALGEBRAIC(:,144) = ALGEBRAIC(:,114);
    ALGEBRAIC(:,31) = CONSTANTS(:,123)+STATES(:,22)+STATES(:,26);
    ALGEBRAIC(:,67) =  CONSTANTS(:,134).*CONSTANTS(:,135).*log( CONSTANTS(:,83).*ALGEBRAIC(:,31));
    ALGEBRAIC(:,116) =  CONSTANTS(:,134).*CONSTANTS(:,135).*log( CONSTANTS(:,94).*STATES(:,56));
    ALGEBRAIC(:,147) = ALGEBRAIC(:,116)+ CONSTANTS(:,168).*ALGEBRAIC(:,67);
    ALGEBRAIC(:,182) =  CONSTANTS(:,49).*(exp(ALGEBRAIC(:,144)./( CONSTANTS(:,134).*CONSTANTS(:,135))) - exp(ALGEBRAIC(:,147)./( CONSTANTS(:,134).*CONSTANTS(:,135))));
    ALGEBRAIC(:,184) =  CONSTANTS(:,168).*ALGEBRAIC(:,182);
    RATES(:,26) = ALGEBRAIC(:,184);
    ALGEBRAIC(:,185) = ALGEBRAIC(:,167) - ALGEBRAIC(:,182);
    RATES(:,55) = ALGEBRAIC(:,185);
    ALGEBRAIC(:,151) = ALGEBRAIC(:,116)+ CONSTANTS(:,169).*ALGEBRAIC(:,72);
    ALGEBRAIC(:,118) =  CONSTANTS(:,134).*CONSTANTS(:,135).*log( CONSTANTS(:,95).*STATES(:,57));
    ALGEBRAIC(:,153) = ALGEBRAIC(:,118);
    ALGEBRAIC(:,186) =  CONSTANTS(:,50).*(exp(ALGEBRAIC(:,151)./( CONSTANTS(:,134).*CONSTANTS(:,135))) - exp(ALGEBRAIC(:,153)./( CONSTANTS(:,134).*CONSTANTS(:,135))));
    ALGEBRAIC(:,188) = ALGEBRAIC(:,182) - ALGEBRAIC(:,186);
    RATES(:,56) = ALGEBRAIC(:,188);
    ALGEBRAIC(:,155) = ALGEBRAIC(:,118);
    ALGEBRAIC(:,157) = ALGEBRAIC(:,72)+ALGEBRAIC(:,112);
    ALGEBRAIC(:,189) =  CONSTANTS(:,51).*(exp(ALGEBRAIC(:,155)./( CONSTANTS(:,134).*CONSTANTS(:,135))) - exp(ALGEBRAIC(:,157)./( CONSTANTS(:,134).*CONSTANTS(:,135))));
    ALGEBRAIC(:,191) = (( CONSTANTS(:,169).*ALGEBRAIC(:,178) - ALGEBRAIC(:,171)) -  CONSTANTS(:,169).*ALGEBRAIC(:,186))+ALGEBRAIC(:,189);
    RATES(:,24) = ALGEBRAIC(:,191);
    ALGEBRAIC(:,193) = ALGEBRAIC(:,189) - ALGEBRAIC(:,159);
    RATES(:,54) = ALGEBRAIC(:,193);
    ALGEBRAIC(:,192) = ALGEBRAIC(:,186) - ALGEBRAIC(:,189);
    RATES(:,57) = ALGEBRAIC(:,192);
    ALGEBRAIC(:,187) =  CONSTANTS(:,16).*(exp((ALGEBRAIC(:,88)+ CONSTANTS(:,158).*CONSTANTS(:,104).*ALGEBRAIC(:,50))./CONSTANTS(:,178)) - exp((ALGEBRAIC(:,97)+ CONSTANTS(:,162).*CONSTANTS(:,104).*ALGEBRAIC(:,50))./CONSTANTS(:,178)));
    ALGEBRAIC(:,190) =  CONSTANTS(:,20).*(exp((ALGEBRAIC(:,88)+ CONSTANTS(:,159).*CONSTANTS(:,104).*ALGEBRAIC(:,50))./CONSTANTS(:,178)) - exp((ALGEBRAIC(:,105)+ CONSTANTS(:,163).*CONSTANTS(:,104).*ALGEBRAIC(:,50))./CONSTANTS(:,178)));
    ALGEBRAIC(:,164) =  CONSTANTS(:,10).*(exp((ALGEBRAIC(:,88)+ CONSTANTS(:,157).*CONSTANTS(:,104).*ALGEBRAIC(:,50))./CONSTANTS(:,178)) - exp((ALGEBRAIC(:,111)+ CONSTANTS(:,161).*CONSTANTS(:,104).*ALGEBRAIC(:,50))./CONSTANTS(:,178)));
    ALGEBRAIC(:,195) = (( - ALGEBRAIC(:,164) - ALGEBRAIC(:,187)) - ALGEBRAIC(:,190)) - ALGEBRAIC(:,150);
    RATES(:,33) = ALGEBRAIC(:,195);
    ALGEBRAIC(:,194) =  CONSTANTS(:,24).*(exp((ALGEBRAIC(:,97)+ CONSTANTS(:,160).*CONSTANTS(:,104).*ALGEBRAIC(:,50))./CONSTANTS(:,178)) - exp((ALGEBRAIC(:,105)+ CONSTANTS(:,164).*CONSTANTS(:,104).*ALGEBRAIC(:,50))./CONSTANTS(:,178)));
    ALGEBRAIC(:,172) =  CONSTANTS(:,12).*(exp((ALGEBRAIC(:,105)+ CONSTANTS(:,157).*CONSTANTS(:,104).*ALGEBRAIC(:,50))./CONSTANTS(:,178)) - exp((ALGEBRAIC(:,131)+ CONSTANTS(:,161).*CONSTANTS(:,104).*ALGEBRAIC(:,50))./CONSTANTS(:,178)));
    ALGEBRAIC(:,197) = ( - ALGEBRAIC(:,172)+ALGEBRAIC(:,194)+ALGEBRAIC(:,190)) - ALGEBRAIC(:,154);
    RATES(:,35) = ALGEBRAIC(:,197);
    ALGEBRAIC(:,196) =  CONSTANTS(:,17).*(exp((ALGEBRAIC(:,111)+ CONSTANTS(:,158).*CONSTANTS(:,104).*ALGEBRAIC(:,50))./CONSTANTS(:,178)) - exp((ALGEBRAIC(:,115)+ CONSTANTS(:,162).*CONSTANTS(:,104).*ALGEBRAIC(:,50))./CONSTANTS(:,178)));
    ALGEBRAIC(:,169) =  CONSTANTS(:,11).*(exp((ALGEBRAIC(:,97)+ CONSTANTS(:,157).*CONSTANTS(:,104).*ALGEBRAIC(:,50))./CONSTANTS(:,178)) - exp((ALGEBRAIC(:,115)+ CONSTANTS(:,161).*CONSTANTS(:,104).*ALGEBRAIC(:,50))./CONSTANTS(:,178)));
    ALGEBRAIC(:,199) = (( - ALGEBRAIC(:,169) - ALGEBRAIC(:,194))+ALGEBRAIC(:,196)) - ALGEBRAIC(:,152);
    RATES(:,34) = ALGEBRAIC(:,199);
    ALGEBRAIC(:,198) =  CONSTANTS(:,21).*(exp((ALGEBRAIC(:,111)+ CONSTANTS(:,159).*CONSTANTS(:,104).*ALGEBRAIC(:,50))./CONSTANTS(:,178)) - exp((ALGEBRAIC(:,131)+ CONSTANTS(:,163).*CONSTANTS(:,104).*ALGEBRAIC(:,50))./CONSTANTS(:,178)));
    ALGEBRAIC(:,201) = (( - ALGEBRAIC(:,198)+ALGEBRAIC(:,164)) - ALGEBRAIC(:,196)) - ALGEBRAIC(:,156);
    RATES(:,36) = ALGEBRAIC(:,201);
    ALGEBRAIC(:,200) =  CONSTANTS(:,25).*(exp((ALGEBRAIC(:,115)+ CONSTANTS(:,160).*CONSTANTS(:,104).*ALGEBRAIC(:,50))./CONSTANTS(:,178)) - exp((ALGEBRAIC(:,131)+ CONSTANTS(:,164).*CONSTANTS(:,104).*ALGEBRAIC(:,50))./CONSTANTS(:,178)));
    ALGEBRAIC(:,203) = ((ALGEBRAIC(:,196)+ALGEBRAIC(:,169)) - ALGEBRAIC(:,158)) - ALGEBRAIC(:,200);
    RATES(:,37) = ALGEBRAIC(:,203);
    ALGEBRAIC(:,204) = ((ALGEBRAIC(:,198)+ALGEBRAIC(:,172)) - ALGEBRAIC(:,160))+ALGEBRAIC(:,200);
    RATES(:,38) = ALGEBRAIC(:,204);
    ALGEBRAIC(:,175) =  CONSTANTS(:,13).*(exp((ALGEBRAIC(:,93)+ CONSTANTS(:,157).*CONSTANTS(:,104).*ALGEBRAIC(:,50))./CONSTANTS(:,178)) - exp((ALGEBRAIC(:,113)+ CONSTANTS(:,161).*CONSTANTS(:,104).*ALGEBRAIC(:,50))./CONSTANTS(:,178)));
    ALGEBRAIC(:,202) =  CONSTANTS(:,18).*(exp((ALGEBRAIC(:,93)+ CONSTANTS(:,158).*CONSTANTS(:,104).*ALGEBRAIC(:,50))./CONSTANTS(:,178)) - exp((ALGEBRAIC(:,101)+ CONSTANTS(:,162).*CONSTANTS(:,104).*ALGEBRAIC(:,50))./CONSTANTS(:,178)));
    ALGEBRAIC(:,205) =  CONSTANTS(:,22).*(exp((ALGEBRAIC(:,93)+ CONSTANTS(:,159).*CONSTANTS(:,104).*ALGEBRAIC(:,50))./CONSTANTS(:,178)) - exp((ALGEBRAIC(:,109)+ CONSTANTS(:,163).*CONSTANTS(:,104).*ALGEBRAIC(:,50))./CONSTANTS(:,178)));
    ALGEBRAIC(:,207) = (( - ALGEBRAIC(:,175) - ALGEBRAIC(:,202)) - ALGEBRAIC(:,205))+ALGEBRAIC(:,150);
    RATES(:,39) = ALGEBRAIC(:,207);
    ALGEBRAIC(:,183) =  CONSTANTS(:,15).*(exp((ALGEBRAIC(:,109)+ CONSTANTS(:,157).*CONSTANTS(:,104).*ALGEBRAIC(:,50))./CONSTANTS(:,178)) - exp((ALGEBRAIC(:,133)+ CONSTANTS(:,161).*CONSTANTS(:,104).*ALGEBRAIC(:,50))./CONSTANTS(:,178)));
    ALGEBRAIC(:,206) =  CONSTANTS(:,26).*(exp((ALGEBRAIC(:,101)+ CONSTANTS(:,160).*CONSTANTS(:,104).*ALGEBRAIC(:,50))./CONSTANTS(:,178)) - exp((ALGEBRAIC(:,109)+ CONSTANTS(:,164).*CONSTANTS(:,104).*ALGEBRAIC(:,50))./CONSTANTS(:,178)));
    ALGEBRAIC(:,209) =  - ALGEBRAIC(:,183)+ALGEBRAIC(:,206)+ALGEBRAIC(:,205)+ALGEBRAIC(:,154);
    RATES(:,41) = ALGEBRAIC(:,209);
    ALGEBRAIC(:,179) =  CONSTANTS(:,14).*(exp((ALGEBRAIC(:,101)+ CONSTANTS(:,157).*CONSTANTS(:,104).*ALGEBRAIC(:,50))./CONSTANTS(:,178)) - exp((ALGEBRAIC(:,117)+ CONSTANTS(:,161).*CONSTANTS(:,104).*ALGEBRAIC(:,50))./CONSTANTS(:,178)));
    ALGEBRAIC(:,208) =  CONSTANTS(:,19).*(exp((ALGEBRAIC(:,113)+ CONSTANTS(:,158).*CONSTANTS(:,104).*ALGEBRAIC(:,50))./CONSTANTS(:,178)) - exp((ALGEBRAIC(:,117)+ CONSTANTS(:,162).*CONSTANTS(:,104).*ALGEBRAIC(:,50))./CONSTANTS(:,178)));
    ALGEBRAIC(:,211) = ( - ALGEBRAIC(:,179) - ALGEBRAIC(:,206))+ALGEBRAIC(:,208)+ALGEBRAIC(:,152);
    RATES(:,40) = ALGEBRAIC(:,211);
    ALGEBRAIC(:,210) =  CONSTANTS(:,23).*(exp((ALGEBRAIC(:,113)+ CONSTANTS(:,159).*CONSTANTS(:,104).*ALGEBRAIC(:,50))./CONSTANTS(:,178)) - exp((ALGEBRAIC(:,133)+ CONSTANTS(:,163).*CONSTANTS(:,104).*ALGEBRAIC(:,50))./CONSTANTS(:,178)));
    ALGEBRAIC(:,213) = (( - ALGEBRAIC(:,210)+ALGEBRAIC(:,175)) - ALGEBRAIC(:,208))+ALGEBRAIC(:,156);
    RATES(:,42) = ALGEBRAIC(:,213);
    ALGEBRAIC(:,212) =  CONSTANTS(:,27).*(exp((ALGEBRAIC(:,117)+ CONSTANTS(:,160).*CONSTANTS(:,104).*ALGEBRAIC(:,50))./CONSTANTS(:,178)) - exp((ALGEBRAIC(:,133)+ CONSTANTS(:,164).*CONSTANTS(:,104).*ALGEBRAIC(:,50))./CONSTANTS(:,178)));
    ALGEBRAIC(:,214) = (ALGEBRAIC(:,208)+ALGEBRAIC(:,179)+ALGEBRAIC(:,158)) - ALGEBRAIC(:,212);
    RATES(:,43) = ALGEBRAIC(:,214);
    ALGEBRAIC(:,215) = ALGEBRAIC(:,210)+ALGEBRAIC(:,183)+ALGEBRAIC(:,160)+ALGEBRAIC(:,212);
    RATES(:,44) = ALGEBRAIC(:,215);
    ALGEBRAIC(:,44) = STATES(:,1)./CONSTANTS(:,103);
    ALGEBRAIC(:,218) =  CONSTANTS(:,134).*CONSTANTS(:,135).*log( CONSTANTS(:,83).*ALGEBRAIC(:,31));
    ALGEBRAIC(:,219) =  CONSTANTS(:,134).*CONSTANTS(:,135).*log( CONSTANTS(:,54).*ALGEBRAIC(:,14));
    ALGEBRAIC(:,223) =  CONSTANTS(:,134).*CONSTANTS(:,135).*log( CONSTANTS(:,87).*STATES(:,48));
    ALGEBRAIC(:,224) =  CONSTANTS(:,39).*exp(ALGEBRAIC(:,223)./( CONSTANTS(:,134).*CONSTANTS(:,135))).*(exp((ALGEBRAIC(:,218)+ CONSTANTS(:,132).*CONSTANTS(:,104).*ALGEBRAIC(:,44))./( CONSTANTS(:,134).*CONSTANTS(:,135))) - exp(ALGEBRAIC(:,219)./( CONSTANTS(:,134).*CONSTANTS(:,135))));
    RATES(:,22) =  - ALGEBRAIC(:,224);
    ALGEBRAIC(:,39) = piecewise({VOI>CONSTANTS(:,128)&VOI<CONSTANTS(:,129), CONSTANTS(:,130) }, CONSTANTS(:,131));
    ALGEBRAIC(:,225) =  CONSTANTS(:,132).*ALGEBRAIC(:,224).*CONSTANTS(:,104);
    ALGEBRAIC(:,216) =  ALGEBRAIC(:,205).*(CONSTANTS(:,163) - CONSTANTS(:,159))+ ALGEBRAIC(:,206).*(CONSTANTS(:,164) - CONSTANTS(:,160))+ ALGEBRAIC(:,208).*(CONSTANTS(:,162) - CONSTANTS(:,158))+ ALGEBRAIC(:,210).*(CONSTANTS(:,163) - CONSTANTS(:,159))+ ALGEBRAIC(:,212).*(CONSTANTS(:,164) - CONSTANTS(:,160))+ ALGEBRAIC(:,202).*(CONSTANTS(:,162) - CONSTANTS(:,158))+ ALGEBRAIC(:,183).*(CONSTANTS(:,161) - CONSTANTS(:,157))+ ALGEBRAIC(:,179).*(CONSTANTS(:,161) - CONSTANTS(:,157))+ ALGEBRAIC(:,175).*(CONSTANTS(:,161) - CONSTANTS(:,157))+ ALGEBRAIC(:,200).*(CONSTANTS(:,164) - CONSTANTS(:,160))+ ALGEBRAIC(:,198).*(CONSTANTS(:,163) - CONSTANTS(:,159))+ ALGEBRAIC(:,196).*(CONSTANTS(:,162) - CONSTANTS(:,158))+ ALGEBRAIC(:,194).*(CONSTANTS(:,164) - CONSTANTS(:,160))+ ALGEBRAIC(:,190).*(CONSTANTS(:,163) - CONSTANTS(:,159))+ ALGEBRAIC(:,187).*(CONSTANTS(:,162) - CONSTANTS(:,158))+ ALGEBRAIC(:,172).*(CONSTANTS(:,161) - CONSTANTS(:,157))+ ALGEBRAIC(:,169).*(CONSTANTS(:,161) - CONSTANTS(:,157))+ ALGEBRAIC(:,164).*(CONSTANTS(:,161) - CONSTANTS(:,157));
    ALGEBRAIC(:,217) =  CONSTANTS(:,104).*((ALGEBRAIC(:,216) -  CONSTANTS(:,132).*(ALGEBRAIC(:,127)+ALGEBRAIC(:,143))) -  CONSTANTS(:,133).*(ALGEBRAIC(:,129)+ALGEBRAIC(:,146)));
    ALGEBRAIC(:,227) = ( - ALGEBRAIC(:,225) - ALGEBRAIC(:,217))+ALGEBRAIC(:,39);
    RATES(:,1) = ALGEBRAIC(:,227);
    ALGEBRAIC(:,220) =  CONSTANTS(:,134).*CONSTANTS(:,135).*log( CONSTANTS(:,84).*STATES(:,45));
    ALGEBRAIC(:,226) =  CONSTANTS(:,40).*(exp(ALGEBRAIC(:,223)./( CONSTANTS(:,134).*CONSTANTS(:,135))) - exp((ALGEBRAIC(:,220)+ CONSTANTS(:,166).*ALGEBRAIC(:,219))./( CONSTANTS(:,134).*CONSTANTS(:,135))));
    ALGEBRAIC(:,221) =  CONSTANTS(:,134).*CONSTANTS(:,135).*log( CONSTANTS(:,85).*STATES(:,46));
    ALGEBRAIC(:,228) =  CONSTANTS(:,41).*(exp((ALGEBRAIC(:,220)+ CONSTANTS(:,165).*ALGEBRAIC(:,219))./( CONSTANTS(:,134).*CONSTANTS(:,135))) - exp(ALGEBRAIC(:,221)./( CONSTANTS(:,134).*CONSTANTS(:,135))));
    RATES(:,45) = ALGEBRAIC(:,226) - ALGEBRAIC(:,228);
    ALGEBRAIC(:,222) =  CONSTANTS(:,134).*CONSTANTS(:,135).*log( CONSTANTS(:,86).*STATES(:,47));
    ALGEBRAIC(:,229) =  CONSTANTS(:,42).*(exp((ALGEBRAIC(:,221)+ CONSTANTS(:,166).*ALGEBRAIC(:,219))./( CONSTANTS(:,134).*CONSTANTS(:,135))) - exp(ALGEBRAIC(:,222)./( CONSTANTS(:,134).*CONSTANTS(:,135))));
    RATES(:,46) = ALGEBRAIC(:,228) - ALGEBRAIC(:,229);
    ALGEBRAIC(:,230) =  CONSTANTS(:,43).*(exp(ALGEBRAIC(:,222)./( CONSTANTS(:,134).*CONSTANTS(:,135))) - exp((ALGEBRAIC(:,223)+ CONSTANTS(:,165).*ALGEBRAIC(:,219))./( CONSTANTS(:,134).*CONSTANTS(:,135))));
    RATES(:,48) = ALGEBRAIC(:,230) - ALGEBRAIC(:,226);
    RATES(:,47) = ALGEBRAIC(:,229) - ALGEBRAIC(:,230);
    ALGEBRAIC(:,231) = (( CONSTANTS(:,166).*ALGEBRAIC(:,226) -  CONSTANTS(:,165).*ALGEBRAIC(:,228)) -  CONSTANTS(:,166).*ALGEBRAIC(:,229))+ CONSTANTS(:,165).*ALGEBRAIC(:,230);
    RATES(:,23) = ALGEBRAIC(:,224)+ALGEBRAIC(:,231);
   RATES = RATES';
end

% Calculate algebraic variables
function ALGEBRAIC = computeAlgebraic(ALGEBRAIC, CONSTANTS, STATES, VOI)
    statesSize = size(STATES);
    statesColumnCount = statesSize(2);
    if ( statesColumnCount == 1)
        STATES = STATES';
        utilOnes = 1;
    else
        statesRowCount = statesSize(1);
        utilOnes = ones(statesRowCount, 1);
    end
    ALGEBRAIC(:,2) =  CONSTANTS(:,171).*STATES(:,30).*CONSTANTS(:,150);
    ALGEBRAIC(:,12) =  - CONSTANTS(:,177) - ALGEBRAIC(:,2);
    ALGEBRAIC(:,16) = ALGEBRAIC(:,12)./CONSTANTS(:,150);
    ALGEBRAIC(:,3) =  CONSTANTS(:,172).*STATES(:,31).*CONSTANTS(:,150);
    ALGEBRAIC(:,13) =  - CONSTANTS(:,180) - ALGEBRAIC(:,3);
    ALGEBRAIC(:,17) = ALGEBRAIC(:,13)./CONSTANTS(:,150);
    ALGEBRAIC(:,18) = CONSTANTS(:,106)+STATES(:,4);
    ALGEBRAIC(:,49) =  CONSTANTS(:,134).*CONSTANTS(:,135).*log( CONSTANTS(:,55).*ALGEBRAIC(:,18));
    ALGEBRAIC(:,22) = CONSTANTS(:,108)+STATES(:,5);
    ALGEBRAIC(:,54) =  CONSTANTS(:,134).*CONSTANTS(:,135).*log( CONSTANTS(:,56).*ALGEBRAIC(:,22));
    ALGEBRAIC(:,25) = CONSTANTS(:,109)+STATES(:,6);
    ALGEBRAIC(:,58) =  CONSTANTS(:,134).*CONSTANTS(:,135).*log( CONSTANTS(:,57).*ALGEBRAIC(:,25));
    ALGEBRAIC(:,73) =  CONSTANTS(:,2).*(exp((ALGEBRAIC(:,54)+ CONSTANTS(:,138).*ALGEBRAIC(:,49))./( CONSTANTS(:,134).*CONSTANTS(:,135))) - exp((ALGEBRAIC(:,58)+ CONSTANTS(:,138).*ALGEBRAIC(:,49))./( CONSTANTS(:,134).*CONSTANTS(:,135))));
    ALGEBRAIC(:,81) = ALGEBRAIC(:,75)./CONSTANTS(:,150);
    ALGEBRAIC(:,29) = CONSTANTS(:,110)+STATES(:,7);
    ALGEBRAIC(:,63) =  CONSTANTS(:,134).*CONSTANTS(:,135).*log( CONSTANTS(:,58).*ALGEBRAIC(:,29));
    ALGEBRAIC(:,82) =  CONSTANTS(:,3).*(exp(ALGEBRAIC(:,58)./( CONSTANTS(:,134).*CONSTANTS(:,135))) - exp(ALGEBRAIC(:,63)./( CONSTANTS(:,134).*CONSTANTS(:,135))));
    ALGEBRAIC(:,34) = CONSTANTS(:,111)+STATES(:,8);
    ALGEBRAIC(:,68) =  CONSTANTS(:,134).*CONSTANTS(:,135).*log( CONSTANTS(:,59).*ALGEBRAIC(:,34));
    ALGEBRAIC(:,87) =  CONSTANTS(:,4).*(exp(ALGEBRAIC(:,63)./( CONSTANTS(:,134).*CONSTANTS(:,135))) - exp(ALGEBRAIC(:,68)./( CONSTANTS(:,134).*CONSTANTS(:,135))));
    ALGEBRAIC(:,92) =  CONSTANTS(:,5).*(exp(ALGEBRAIC(:,68)./( CONSTANTS(:,134).*CONSTANTS(:,135))) - exp(ALGEBRAIC(:,58)./( CONSTANTS(:,134).*CONSTANTS(:,135))));
    ALGEBRAIC(:,1) = CONSTANTS(:,115)+STATES(:,14);
    ALGEBRAIC(:,46) =  CONSTANTS(:,134).*CONSTANTS(:,135).*log( CONSTANTS(:,75).*ALGEBRAIC(:,1));
    ALGEBRAIC(:,11) = CONSTANTS(:,116)+STATES(:,15);
    ALGEBRAIC(:,51) =  CONSTANTS(:,134).*CONSTANTS(:,135).*log( CONSTANTS(:,76).*ALGEBRAIC(:,11));
    ALGEBRAIC(:,15) = CONSTANTS(:,117)+STATES(:,16);
    ALGEBRAIC(:,57) =  CONSTANTS(:,134).*CONSTANTS(:,135).*log( CONSTANTS(:,77).*ALGEBRAIC(:,15));
    ALGEBRAIC(:,89) =  CONSTANTS(:,34).*(exp((ALGEBRAIC(:,46)+ALGEBRAIC(:,51))./( CONSTANTS(:,134).*CONSTANTS(:,135))) - exp(ALGEBRAIC(:,57)./( CONSTANTS(:,134).*CONSTANTS(:,135))));
    ALGEBRAIC(:,26) = CONSTANTS(:,120)+STATES(:,19);
    ALGEBRAIC(:,71) =  CONSTANTS(:,134).*CONSTANTS(:,135).*log( CONSTANTS(:,80).*ALGEBRAIC(:,26));
    ALGEBRAIC(:,94) =  CONSTANTS(:,35).*(exp(ALGEBRAIC(:,57)./( CONSTANTS(:,134).*CONSTANTS(:,135))) - exp((ALGEBRAIC(:,71)+ALGEBRAIC(:,51))./( CONSTANTS(:,134).*CONSTANTS(:,135))));
    ALGEBRAIC(:,19) = CONSTANTS(:,118)+STATES(:,17);
    ALGEBRAIC(:,61) =  CONSTANTS(:,134).*CONSTANTS(:,135).*log( CONSTANTS(:,78).*ALGEBRAIC(:,19));
    ALGEBRAIC(:,23) = CONSTANTS(:,119)+STATES(:,18);
    ALGEBRAIC(:,66) =  CONSTANTS(:,134).*CONSTANTS(:,135).*log( CONSTANTS(:,79).*ALGEBRAIC(:,23));
    ALGEBRAIC(:,98) =  CONSTANTS(:,36).*(exp((ALGEBRAIC(:,71)+ALGEBRAIC(:,61))./( CONSTANTS(:,134).*CONSTANTS(:,135))) - exp(ALGEBRAIC(:,66)./( CONSTANTS(:,134).*CONSTANTS(:,135))));
    ALGEBRAIC(:,102) =  CONSTANTS(:,37).*(exp(ALGEBRAIC(:,66)./( CONSTANTS(:,134).*CONSTANTS(:,135))) - exp((ALGEBRAIC(:,46)+ALGEBRAIC(:,61))./( CONSTANTS(:,134).*CONSTANTS(:,135))));
    ALGEBRAIC(:,30) = CONSTANTS(:,121)+STATES(:,20);
    ALGEBRAIC(:,79) =  CONSTANTS(:,134).*CONSTANTS(:,135).*log( CONSTANTS(:,81).*ALGEBRAIC(:,30));
    ALGEBRAIC(:,35) = CONSTANTS(:,122)+STATES(:,21);
    ALGEBRAIC(:,84) =  CONSTANTS(:,134).*CONSTANTS(:,135).*log( CONSTANTS(:,82).*ALGEBRAIC(:,35));
    ALGEBRAIC(:,106) =  CONSTANTS(:,38).*(exp((ALGEBRAIC(:,61)+ALGEBRAIC(:,79))./( CONSTANTS(:,134).*CONSTANTS(:,135))) - exp(ALGEBRAIC(:,84)./( CONSTANTS(:,134).*CONSTANTS(:,135))));
    ALGEBRAIC(:,4) = CONSTANTS(:,105)+STATES(:,2);
    ALGEBRAIC(:,38) =  CONSTANTS(:,134).*CONSTANTS(:,135).*log( CONSTANTS(:,53).*ALGEBRAIC(:,4));
    ALGEBRAIC(:,14) = CONSTANTS(:,107)+STATES(:,3)+STATES(:,10)+STATES(:,23)+STATES(:,25);
    ALGEBRAIC(:,43) =  CONSTANTS(:,134).*CONSTANTS(:,135).*log( CONSTANTS(:,54).*ALGEBRAIC(:,14));
    ALGEBRAIC(:,55) =  (CONSTANTS(:,151)./( CONSTANTS(:,141).*CONSTANTS(:,142).*CONSTANTS(:,143))).*STATES(:,8).*(STATES(:,31)+CONSTANTS(:,141));
    ALGEBRAIC(:,59) =  (CONSTANTS(:,151)./( CONSTANTS(:,141).*CONSTANTS(:,142).*CONSTANTS(:,143))).*STATES(:,7).*STATES(:,30);
    ALGEBRAIC(:,64) = ALGEBRAIC(:,55)+ALGEBRAIC(:,59);
    ALGEBRAIC(:,69) = ALGEBRAIC(:,64);
    ALGEBRAIC(:,86) =  (( CONSTANTS(:,155).*ALGEBRAIC(:,74))./CONSTANTS(:,141)).*ALGEBRAIC(:,81);
    ALGEBRAIC(:,91) = ALGEBRAIC(:,86);
    ALGEBRAIC(:,96) = ALGEBRAIC(:,69)+ALGEBRAIC(:,91);
    ALGEBRAIC(:,100) =  ALGEBRAIC(:,96).*1000.00;
    ALGEBRAIC(:,104) =  CONSTANTS(:,140).*CONSTANTS(:,174).*ALGEBRAIC(:,100);
    ALGEBRAIC(:,108) =  CONSTANTS(:,1).*(exp((ALGEBRAIC(:,43)+ALGEBRAIC(:,38))./( CONSTANTS(:,134).*CONSTANTS(:,135))) - exp((ALGEBRAIC(:,49)+ALGEBRAIC(:,104))./( CONSTANTS(:,134).*CONSTANTS(:,135))));
    ALGEBRAIC(:,50) = STATES(:,1)./CONSTANTS(:,103);
    ALGEBRAIC(:,78) =  CONSTANTS(:,132).*CONSTANTS(:,104).*ALGEBRAIC(:,50);
    ALGEBRAIC(:,56) =  CONSTANTS(:,178).*log( CONSTANTS(:,54).*ALGEBRAIC(:,14));
    ALGEBRAIC(:,117) =  CONSTANTS(:,178).*log( CONSTANTS(:,73).*STATES(:,43));
    ALGEBRAIC(:,119) = ALGEBRAIC(:,56)+ALGEBRAIC(:,78)+ALGEBRAIC(:,117);
    ALGEBRAIC(:,20) = CONSTANTS(:,112)+STATES(:,11);
    ALGEBRAIC(:,60) =  CONSTANTS(:,178).*log( CONSTANTS(:,60).*ALGEBRAIC(:,20));
    ALGEBRAIC(:,121) = ALGEBRAIC(:,60)+ALGEBRAIC(:,117);
    ALGEBRAIC(:,127) = piecewise({ALGEBRAIC(:,78)==0.000000,  CONSTANTS(:,6).*(exp(ALGEBRAIC(:,119)./CONSTANTS(:,178)) - exp(ALGEBRAIC(:,121)./CONSTANTS(:,178))) },  ((( CONSTANTS(:,6).*ALGEBRAIC(:,78))./CONSTANTS(:,178))./(exp(ALGEBRAIC(:,78)./CONSTANTS(:,178)) - 1.00000)).*(exp(ALGEBRAIC(:,119)./CONSTANTS(:,178)) - exp(ALGEBRAIC(:,121)./CONSTANTS(:,178))));
    ALGEBRAIC(:,133) =  CONSTANTS(:,178).*log( CONSTANTS(:,74).*STATES(:,44));
    ALGEBRAIC(:,135) = ALGEBRAIC(:,56)+ALGEBRAIC(:,78)+ALGEBRAIC(:,133);
    ALGEBRAIC(:,137) = ALGEBRAIC(:,60)+ALGEBRAIC(:,133);
    ALGEBRAIC(:,143) = piecewise({ALGEBRAIC(:,78)==0.000000,  CONSTANTS(:,7).*(exp(ALGEBRAIC(:,135)./CONSTANTS(:,178)) - exp(ALGEBRAIC(:,137)./CONSTANTS(:,178))) },  ((( CONSTANTS(:,7).*ALGEBRAIC(:,78))./CONSTANTS(:,178))./(exp(ALGEBRAIC(:,78)./CONSTANTS(:,178)) - 1.00000)).*(exp(ALGEBRAIC(:,135)./CONSTANTS(:,178)) - exp(ALGEBRAIC(:,137)./CONSTANTS(:,178))));
    ALGEBRAIC(:,145) = ALGEBRAIC(:,143)+ALGEBRAIC(:,127);
    ALGEBRAIC(:,83) =  CONSTANTS(:,133).*CONSTANTS(:,104).*ALGEBRAIC(:,50);
    ALGEBRAIC(:,24) = CONSTANTS(:,113)+STATES(:,12);
    ALGEBRAIC(:,65) =  CONSTANTS(:,178).*log( CONSTANTS(:,61).*ALGEBRAIC(:,24));
    ALGEBRAIC(:,123) = ALGEBRAIC(:,65)+ALGEBRAIC(:,83)+ALGEBRAIC(:,117);
    ALGEBRAIC(:,27) = CONSTANTS(:,114)+STATES(:,13);
    ALGEBRAIC(:,70) =  CONSTANTS(:,178).*log( CONSTANTS(:,62).*ALGEBRAIC(:,27));
    ALGEBRAIC(:,125) = ALGEBRAIC(:,70)+ALGEBRAIC(:,117);
    ALGEBRAIC(:,129) = piecewise({ALGEBRAIC(:,83)==0.000000,  CONSTANTS(:,8).*(exp(ALGEBRAIC(:,123)./CONSTANTS(:,178)) - exp(ALGEBRAIC(:,125)./CONSTANTS(:,178))) },  ((( CONSTANTS(:,8).*ALGEBRAIC(:,83))./CONSTANTS(:,178))./(exp(ALGEBRAIC(:,83)./CONSTANTS(:,178)) - 1.00000)).*(exp(ALGEBRAIC(:,123)./CONSTANTS(:,178)) - exp(ALGEBRAIC(:,125)./CONSTANTS(:,178))));
    ALGEBRAIC(:,139) = ALGEBRAIC(:,65)+ALGEBRAIC(:,83)+ALGEBRAIC(:,133);
    ALGEBRAIC(:,141) = ALGEBRAIC(:,70)+ALGEBRAIC(:,133);
    ALGEBRAIC(:,146) = piecewise({ALGEBRAIC(:,83)==0.000000,  CONSTANTS(:,9).*(exp(ALGEBRAIC(:,139)./CONSTANTS(:,178)) - exp(ALGEBRAIC(:,141)./CONSTANTS(:,178))) },  ((( CONSTANTS(:,9).*ALGEBRAIC(:,83))./CONSTANTS(:,178))./(exp(ALGEBRAIC(:,83)./CONSTANTS(:,178)) - 1.00000)).*(exp(ALGEBRAIC(:,139)./CONSTANTS(:,178)) - exp(ALGEBRAIC(:,141)./CONSTANTS(:,178))));
    ALGEBRAIC(:,148) =  - ALGEBRAIC(:,129) - ALGEBRAIC(:,146);
    ALGEBRAIC(:,149) = ALGEBRAIC(:,146)+ALGEBRAIC(:,129);
    ALGEBRAIC(:,112) =  CONSTANTS(:,134).*CONSTANTS(:,135).*log( CONSTANTS(:,96).*STATES(:,54));
    ALGEBRAIC(:,120) = ALGEBRAIC(:,112);
    ALGEBRAIC(:,95) =  CONSTANTS(:,134).*CONSTANTS(:,135).*log( CONSTANTS(:,88).*STATES(:,49));
    ALGEBRAIC(:,52) = CONSTANTS(:,125)+STATES(:,29);
    ALGEBRAIC(:,90) =  CONSTANTS(:,134).*CONSTANTS(:,135).*log( CONSTANTS(:,100).*ALGEBRAIC(:,52));
    ALGEBRAIC(:,122) = ALGEBRAIC(:,95)+ALGEBRAIC(:,90);
    ALGEBRAIC(:,159) =  CONSTANTS(:,52).*(exp(ALGEBRAIC(:,120)./( CONSTANTS(:,134).*CONSTANTS(:,135))) - exp(ALGEBRAIC(:,122)./( CONSTANTS(:,134).*CONSTANTS(:,135))));
    ALGEBRAIC(:,161) = ALGEBRAIC(:,159);
    ALGEBRAIC(:,40) = CONSTANTS(:,127)+STATES(:,27);
    ALGEBRAIC(:,85) =  CONSTANTS(:,134).*CONSTANTS(:,135).*log( CONSTANTS(:,98).*ALGEBRAIC(:,40));
    ALGEBRAIC(:,124) = ALGEBRAIC(:,95)+ALGEBRAIC(:,85);
    ALGEBRAIC(:,99) =  CONSTANTS(:,134).*CONSTANTS(:,135).*log( CONSTANTS(:,89).*STATES(:,50));
    ALGEBRAIC(:,126) = ALGEBRAIC(:,99);
    ALGEBRAIC(:,162) =  CONSTANTS(:,44).*(exp(ALGEBRAIC(:,124)./( CONSTANTS(:,134).*CONSTANTS(:,135))) - exp(ALGEBRAIC(:,126)./( CONSTANTS(:,134).*CONSTANTS(:,135))));
    ALGEBRAIC(:,165) =  - ALGEBRAIC(:,162);
    ALGEBRAIC(:,166) = ALGEBRAIC(:,159) - ALGEBRAIC(:,162);
    ALGEBRAIC(:,88) =  CONSTANTS(:,178).*log( CONSTANTS(:,63).*STATES(:,33));
    ALGEBRAIC(:,93) =  CONSTANTS(:,178).*log( CONSTANTS(:,69).*STATES(:,39));
    ALGEBRAIC(:,150) =  CONSTANTS(:,28).*(exp(ALGEBRAIC(:,88)./CONSTANTS(:,178)) - exp((ALGEBRAIC(:,93)+ CONSTANTS(:,156).*ALGEBRAIC(:,56))./CONSTANTS(:,178)));
    ALGEBRAIC(:,97) =  CONSTANTS(:,178).*log( CONSTANTS(:,64).*STATES(:,34));
    ALGEBRAIC(:,101) =  CONSTANTS(:,178).*log( CONSTANTS(:,70).*STATES(:,40));
    ALGEBRAIC(:,152) =  CONSTANTS(:,30).*(exp(ALGEBRAIC(:,97)./CONSTANTS(:,178)) - exp((ALGEBRAIC(:,101)+ CONSTANTS(:,156).*ALGEBRAIC(:,56))./CONSTANTS(:,178)));
    ALGEBRAIC(:,105) =  CONSTANTS(:,178).*log( CONSTANTS(:,65).*STATES(:,35));
    ALGEBRAIC(:,109) =  CONSTANTS(:,178).*log( CONSTANTS(:,71).*STATES(:,41));
    ALGEBRAIC(:,154) =  CONSTANTS(:,32).*(exp(ALGEBRAIC(:,105)./CONSTANTS(:,178)) - exp((ALGEBRAIC(:,109)+ CONSTANTS(:,156).*ALGEBRAIC(:,56))./CONSTANTS(:,178)));
    ALGEBRAIC(:,111) =  CONSTANTS(:,178).*log( CONSTANTS(:,66).*STATES(:,36));
    ALGEBRAIC(:,113) =  CONSTANTS(:,178).*log( CONSTANTS(:,72).*STATES(:,42));
    ALGEBRAIC(:,156) =  CONSTANTS(:,29).*(exp(ALGEBRAIC(:,111)./CONSTANTS(:,178)) - exp((ALGEBRAIC(:,113)+ CONSTANTS(:,156).*ALGEBRAIC(:,56))./CONSTANTS(:,178)));
    ALGEBRAIC(:,115) =  CONSTANTS(:,178).*log( CONSTANTS(:,67).*STATES(:,37));
    ALGEBRAIC(:,158) =  CONSTANTS(:,31).*(exp(ALGEBRAIC(:,115)./CONSTANTS(:,178)) - exp((ALGEBRAIC(:,117)+ CONSTANTS(:,156).*ALGEBRAIC(:,56))./CONSTANTS(:,178)));
    ALGEBRAIC(:,131) =  CONSTANTS(:,178).*log( CONSTANTS(:,68).*STATES(:,38));
    ALGEBRAIC(:,160) =  CONSTANTS(:,33).*(exp(ALGEBRAIC(:,131)./CONSTANTS(:,178)) - exp((ALGEBRAIC(:,133)+ CONSTANTS(:,156).*ALGEBRAIC(:,56))./CONSTANTS(:,178)));
    ALGEBRAIC(:,163) =  CONSTANTS(:,132).*(ALGEBRAIC(:,156)+ALGEBRAIC(:,158)+ALGEBRAIC(:,154)+ALGEBRAIC(:,152)+ALGEBRAIC(:,150)+ALGEBRAIC(:,160));
    ALGEBRAIC(:,168) = (ALGEBRAIC(:,163) - ALGEBRAIC(:,127)) - ALGEBRAIC(:,143);
    ALGEBRAIC(:,110) =  CONSTANTS(:,134).*CONSTANTS(:,135).*log( CONSTANTS(:,92).*STATES(:,53));
    ALGEBRAIC(:,128) = ALGEBRAIC(:,110);
    ALGEBRAIC(:,47) = CONSTANTS(:,126)+STATES(:,28);
    ALGEBRAIC(:,80) =  CONSTANTS(:,134).*CONSTANTS(:,135).*log( CONSTANTS(:,99).*ALGEBRAIC(:,47));
    ALGEBRAIC(:,114) =  CONSTANTS(:,134).*CONSTANTS(:,135).*log( CONSTANTS(:,93).*STATES(:,55));
    ALGEBRAIC(:,130) = ALGEBRAIC(:,80)+ALGEBRAIC(:,114);
    ALGEBRAIC(:,167) =  CONSTANTS(:,48).*(exp(ALGEBRAIC(:,128)./( CONSTANTS(:,134).*CONSTANTS(:,135))) - exp(ALGEBRAIC(:,130)./( CONSTANTS(:,134).*CONSTANTS(:,135))));
    ALGEBRAIC(:,170) = ALGEBRAIC(:,167);
    ALGEBRAIC(:,36) = CONSTANTS(:,124)+STATES(:,24);
    ALGEBRAIC(:,72) =  CONSTANTS(:,134).*CONSTANTS(:,135).*log( CONSTANTS(:,97).*ALGEBRAIC(:,36));
    ALGEBRAIC(:,132) = ALGEBRAIC(:,99)+ALGEBRAIC(:,72);
    ALGEBRAIC(:,103) =  CONSTANTS(:,134).*CONSTANTS(:,135).*log( CONSTANTS(:,90).*STATES(:,51));
    ALGEBRAIC(:,134) = ALGEBRAIC(:,103);
    ALGEBRAIC(:,171) =  CONSTANTS(:,46).*(exp(ALGEBRAIC(:,132)./( CONSTANTS(:,134).*CONSTANTS(:,135))) - exp(ALGEBRAIC(:,134)./( CONSTANTS(:,134).*CONSTANTS(:,135))));
    ALGEBRAIC(:,173) = ALGEBRAIC(:,171);
    ALGEBRAIC(:,62) =  CONSTANTS(:,134).*CONSTANTS(:,135).*log( CONSTANTS(:,54).*ALGEBRAIC(:,14));
    ALGEBRAIC(:,136) = ALGEBRAIC(:,99)+ CONSTANTS(:,167).*ALGEBRAIC(:,62);
    ALGEBRAIC(:,107) =  CONSTANTS(:,134).*CONSTANTS(:,135).*log( CONSTANTS(:,91).*STATES(:,52));
    ALGEBRAIC(:,138) = ALGEBRAIC(:,107);
    ALGEBRAIC(:,174) =  CONSTANTS(:,45).*(exp(ALGEBRAIC(:,136)./( CONSTANTS(:,134).*CONSTANTS(:,135))) - exp(ALGEBRAIC(:,138)./( CONSTANTS(:,134).*CONSTANTS(:,135))));
    ALGEBRAIC(:,176) =   - CONSTANTS(:,167).*ALGEBRAIC(:,174);
    ALGEBRAIC(:,177) = ALGEBRAIC(:,162) - ALGEBRAIC(:,174);
    ALGEBRAIC(:,140) = ALGEBRAIC(:,107);
    ALGEBRAIC(:,142) = ALGEBRAIC(:,110)+ CONSTANTS(:,169).*ALGEBRAIC(:,72);
    ALGEBRAIC(:,178) =  CONSTANTS(:,47).*(exp(ALGEBRAIC(:,140)./( CONSTANTS(:,134).*CONSTANTS(:,135))) - exp(ALGEBRAIC(:,142)./( CONSTANTS(:,134).*CONSTANTS(:,135))));
    ALGEBRAIC(:,180) = ALGEBRAIC(:,174) - ALGEBRAIC(:,178);
    ALGEBRAIC(:,181) = ALGEBRAIC(:,178) - ALGEBRAIC(:,167);
    ALGEBRAIC(:,144) = ALGEBRAIC(:,114);
    ALGEBRAIC(:,31) = CONSTANTS(:,123)+STATES(:,22)+STATES(:,26);
    ALGEBRAIC(:,67) =  CONSTANTS(:,134).*CONSTANTS(:,135).*log( CONSTANTS(:,83).*ALGEBRAIC(:,31));
    ALGEBRAIC(:,116) =  CONSTANTS(:,134).*CONSTANTS(:,135).*log( CONSTANTS(:,94).*STATES(:,56));
    ALGEBRAIC(:,147) = ALGEBRAIC(:,116)+ CONSTANTS(:,168).*ALGEBRAIC(:,67);
    ALGEBRAIC(:,182) =  CONSTANTS(:,49).*(exp(ALGEBRAIC(:,144)./( CONSTANTS(:,134).*CONSTANTS(:,135))) - exp(ALGEBRAIC(:,147)./( CONSTANTS(:,134).*CONSTANTS(:,135))));
    ALGEBRAIC(:,184) =  CONSTANTS(:,168).*ALGEBRAIC(:,182);
    ALGEBRAIC(:,185) = ALGEBRAIC(:,167) - ALGEBRAIC(:,182);
    ALGEBRAIC(:,151) = ALGEBRAIC(:,116)+ CONSTANTS(:,169).*ALGEBRAIC(:,72);
    ALGEBRAIC(:,118) =  CONSTANTS(:,134).*CONSTANTS(:,135).*log( CONSTANTS(:,95).*STATES(:,57));
    ALGEBRAIC(:,153) = ALGEBRAIC(:,118);
    ALGEBRAIC(:,186) =  CONSTANTS(:,50).*(exp(ALGEBRAIC(:,151)./( CONSTANTS(:,134).*CONSTANTS(:,135))) - exp(ALGEBRAIC(:,153)./( CONSTANTS(:,134).*CONSTANTS(:,135))));
    ALGEBRAIC(:,188) = ALGEBRAIC(:,182) - ALGEBRAIC(:,186);
    ALGEBRAIC(:,155) = ALGEBRAIC(:,118);
    ALGEBRAIC(:,157) = ALGEBRAIC(:,72)+ALGEBRAIC(:,112);
    ALGEBRAIC(:,189) =  CONSTANTS(:,51).*(exp(ALGEBRAIC(:,155)./( CONSTANTS(:,134).*CONSTANTS(:,135))) - exp(ALGEBRAIC(:,157)./( CONSTANTS(:,134).*CONSTANTS(:,135))));
    ALGEBRAIC(:,191) = (( CONSTANTS(:,169).*ALGEBRAIC(:,178) - ALGEBRAIC(:,171)) -  CONSTANTS(:,169).*ALGEBRAIC(:,186))+ALGEBRAIC(:,189);
    ALGEBRAIC(:,193) = ALGEBRAIC(:,189) - ALGEBRAIC(:,159);
    ALGEBRAIC(:,192) = ALGEBRAIC(:,186) - ALGEBRAIC(:,189);
    ALGEBRAIC(:,187) =  CONSTANTS(:,16).*(exp((ALGEBRAIC(:,88)+ CONSTANTS(:,158).*CONSTANTS(:,104).*ALGEBRAIC(:,50))./CONSTANTS(:,178)) - exp((ALGEBRAIC(:,97)+ CONSTANTS(:,162).*CONSTANTS(:,104).*ALGEBRAIC(:,50))./CONSTANTS(:,178)));
    ALGEBRAIC(:,190) =  CONSTANTS(:,20).*(exp((ALGEBRAIC(:,88)+ CONSTANTS(:,159).*CONSTANTS(:,104).*ALGEBRAIC(:,50))./CONSTANTS(:,178)) - exp((ALGEBRAIC(:,105)+ CONSTANTS(:,163).*CONSTANTS(:,104).*ALGEBRAIC(:,50))./CONSTANTS(:,178)));
    ALGEBRAIC(:,164) =  CONSTANTS(:,10).*(exp((ALGEBRAIC(:,88)+ CONSTANTS(:,157).*CONSTANTS(:,104).*ALGEBRAIC(:,50))./CONSTANTS(:,178)) - exp((ALGEBRAIC(:,111)+ CONSTANTS(:,161).*CONSTANTS(:,104).*ALGEBRAIC(:,50))./CONSTANTS(:,178)));
    ALGEBRAIC(:,195) = (( - ALGEBRAIC(:,164) - ALGEBRAIC(:,187)) - ALGEBRAIC(:,190)) - ALGEBRAIC(:,150);
    ALGEBRAIC(:,194) =  CONSTANTS(:,24).*(exp((ALGEBRAIC(:,97)+ CONSTANTS(:,160).*CONSTANTS(:,104).*ALGEBRAIC(:,50))./CONSTANTS(:,178)) - exp((ALGEBRAIC(:,105)+ CONSTANTS(:,164).*CONSTANTS(:,104).*ALGEBRAIC(:,50))./CONSTANTS(:,178)));
    ALGEBRAIC(:,172) =  CONSTANTS(:,12).*(exp((ALGEBRAIC(:,105)+ CONSTANTS(:,157).*CONSTANTS(:,104).*ALGEBRAIC(:,50))./CONSTANTS(:,178)) - exp((ALGEBRAIC(:,131)+ CONSTANTS(:,161).*CONSTANTS(:,104).*ALGEBRAIC(:,50))./CONSTANTS(:,178)));
    ALGEBRAIC(:,197) = ( - ALGEBRAIC(:,172)+ALGEBRAIC(:,194)+ALGEBRAIC(:,190)) - ALGEBRAIC(:,154);
    ALGEBRAIC(:,196) =  CONSTANTS(:,17).*(exp((ALGEBRAIC(:,111)+ CONSTANTS(:,158).*CONSTANTS(:,104).*ALGEBRAIC(:,50))./CONSTANTS(:,178)) - exp((ALGEBRAIC(:,115)+ CONSTANTS(:,162).*CONSTANTS(:,104).*ALGEBRAIC(:,50))./CONSTANTS(:,178)));
    ALGEBRAIC(:,169) =  CONSTANTS(:,11).*(exp((ALGEBRAIC(:,97)+ CONSTANTS(:,157).*CONSTANTS(:,104).*ALGEBRAIC(:,50))./CONSTANTS(:,178)) - exp((ALGEBRAIC(:,115)+ CONSTANTS(:,161).*CONSTANTS(:,104).*ALGEBRAIC(:,50))./CONSTANTS(:,178)));
    ALGEBRAIC(:,199) = (( - ALGEBRAIC(:,169) - ALGEBRAIC(:,194))+ALGEBRAIC(:,196)) - ALGEBRAIC(:,152);
    ALGEBRAIC(:,198) =  CONSTANTS(:,21).*(exp((ALGEBRAIC(:,111)+ CONSTANTS(:,159).*CONSTANTS(:,104).*ALGEBRAIC(:,50))./CONSTANTS(:,178)) - exp((ALGEBRAIC(:,131)+ CONSTANTS(:,163).*CONSTANTS(:,104).*ALGEBRAIC(:,50))./CONSTANTS(:,178)));
    ALGEBRAIC(:,201) = (( - ALGEBRAIC(:,198)+ALGEBRAIC(:,164)) - ALGEBRAIC(:,196)) - ALGEBRAIC(:,156);
    ALGEBRAIC(:,200) =  CONSTANTS(:,25).*(exp((ALGEBRAIC(:,115)+ CONSTANTS(:,160).*CONSTANTS(:,104).*ALGEBRAIC(:,50))./CONSTANTS(:,178)) - exp((ALGEBRAIC(:,131)+ CONSTANTS(:,164).*CONSTANTS(:,104).*ALGEBRAIC(:,50))./CONSTANTS(:,178)));
    ALGEBRAIC(:,203) = ((ALGEBRAIC(:,196)+ALGEBRAIC(:,169)) - ALGEBRAIC(:,158)) - ALGEBRAIC(:,200);
    ALGEBRAIC(:,204) = ((ALGEBRAIC(:,198)+ALGEBRAIC(:,172)) - ALGEBRAIC(:,160))+ALGEBRAIC(:,200);
    ALGEBRAIC(:,175) =  CONSTANTS(:,13).*(exp((ALGEBRAIC(:,93)+ CONSTANTS(:,157).*CONSTANTS(:,104).*ALGEBRAIC(:,50))./CONSTANTS(:,178)) - exp((ALGEBRAIC(:,113)+ CONSTANTS(:,161).*CONSTANTS(:,104).*ALGEBRAIC(:,50))./CONSTANTS(:,178)));
    ALGEBRAIC(:,202) =  CONSTANTS(:,18).*(exp((ALGEBRAIC(:,93)+ CONSTANTS(:,158).*CONSTANTS(:,104).*ALGEBRAIC(:,50))./CONSTANTS(:,178)) - exp((ALGEBRAIC(:,101)+ CONSTANTS(:,162).*CONSTANTS(:,104).*ALGEBRAIC(:,50))./CONSTANTS(:,178)));
    ALGEBRAIC(:,205) =  CONSTANTS(:,22).*(exp((ALGEBRAIC(:,93)+ CONSTANTS(:,159).*CONSTANTS(:,104).*ALGEBRAIC(:,50))./CONSTANTS(:,178)) - exp((ALGEBRAIC(:,109)+ CONSTANTS(:,163).*CONSTANTS(:,104).*ALGEBRAIC(:,50))./CONSTANTS(:,178)));
    ALGEBRAIC(:,207) = (( - ALGEBRAIC(:,175) - ALGEBRAIC(:,202)) - ALGEBRAIC(:,205))+ALGEBRAIC(:,150);
    ALGEBRAIC(:,183) =  CONSTANTS(:,15).*(exp((ALGEBRAIC(:,109)+ CONSTANTS(:,157).*CONSTANTS(:,104).*ALGEBRAIC(:,50))./CONSTANTS(:,178)) - exp((ALGEBRAIC(:,133)+ CONSTANTS(:,161).*CONSTANTS(:,104).*ALGEBRAIC(:,50))./CONSTANTS(:,178)));
    ALGEBRAIC(:,206) =  CONSTANTS(:,26).*(exp((ALGEBRAIC(:,101)+ CONSTANTS(:,160).*CONSTANTS(:,104).*ALGEBRAIC(:,50))./CONSTANTS(:,178)) - exp((ALGEBRAIC(:,109)+ CONSTANTS(:,164).*CONSTANTS(:,104).*ALGEBRAIC(:,50))./CONSTANTS(:,178)));
    ALGEBRAIC(:,209) =  - ALGEBRAIC(:,183)+ALGEBRAIC(:,206)+ALGEBRAIC(:,205)+ALGEBRAIC(:,154);
    ALGEBRAIC(:,179) =  CONSTANTS(:,14).*(exp((ALGEBRAIC(:,101)+ CONSTANTS(:,157).*CONSTANTS(:,104).*ALGEBRAIC(:,50))./CONSTANTS(:,178)) - exp((ALGEBRAIC(:,117)+ CONSTANTS(:,161).*CONSTANTS(:,104).*ALGEBRAIC(:,50))./CONSTANTS(:,178)));
    ALGEBRAIC(:,208) =  CONSTANTS(:,19).*(exp((ALGEBRAIC(:,113)+ CONSTANTS(:,158).*CONSTANTS(:,104).*ALGEBRAIC(:,50))./CONSTANTS(:,178)) - exp((ALGEBRAIC(:,117)+ CONSTANTS(:,162).*CONSTANTS(:,104).*ALGEBRAIC(:,50))./CONSTANTS(:,178)));
    ALGEBRAIC(:,211) = ( - ALGEBRAIC(:,179) - ALGEBRAIC(:,206))+ALGEBRAIC(:,208)+ALGEBRAIC(:,152);
    ALGEBRAIC(:,210) =  CONSTANTS(:,23).*(exp((ALGEBRAIC(:,113)+ CONSTANTS(:,159).*CONSTANTS(:,104).*ALGEBRAIC(:,50))./CONSTANTS(:,178)) - exp((ALGEBRAIC(:,133)+ CONSTANTS(:,163).*CONSTANTS(:,104).*ALGEBRAIC(:,50))./CONSTANTS(:,178)));
    ALGEBRAIC(:,213) = (( - ALGEBRAIC(:,210)+ALGEBRAIC(:,175)) - ALGEBRAIC(:,208))+ALGEBRAIC(:,156);
    ALGEBRAIC(:,212) =  CONSTANTS(:,27).*(exp((ALGEBRAIC(:,117)+ CONSTANTS(:,160).*CONSTANTS(:,104).*ALGEBRAIC(:,50))./CONSTANTS(:,178)) - exp((ALGEBRAIC(:,133)+ CONSTANTS(:,164).*CONSTANTS(:,104).*ALGEBRAIC(:,50))./CONSTANTS(:,178)));
    ALGEBRAIC(:,214) = (ALGEBRAIC(:,208)+ALGEBRAIC(:,179)+ALGEBRAIC(:,158)) - ALGEBRAIC(:,212);
    ALGEBRAIC(:,215) = ALGEBRAIC(:,210)+ALGEBRAIC(:,183)+ALGEBRAIC(:,160)+ALGEBRAIC(:,212);
    ALGEBRAIC(:,44) = STATES(:,1)./CONSTANTS(:,103);
    ALGEBRAIC(:,218) =  CONSTANTS(:,134).*CONSTANTS(:,135).*log( CONSTANTS(:,83).*ALGEBRAIC(:,31));
    ALGEBRAIC(:,219) =  CONSTANTS(:,134).*CONSTANTS(:,135).*log( CONSTANTS(:,54).*ALGEBRAIC(:,14));
    ALGEBRAIC(:,223) =  CONSTANTS(:,134).*CONSTANTS(:,135).*log( CONSTANTS(:,87).*STATES(:,48));
    ALGEBRAIC(:,224) =  CONSTANTS(:,39).*exp(ALGEBRAIC(:,223)./( CONSTANTS(:,134).*CONSTANTS(:,135))).*(exp((ALGEBRAIC(:,218)+ CONSTANTS(:,132).*CONSTANTS(:,104).*ALGEBRAIC(:,44))./( CONSTANTS(:,134).*CONSTANTS(:,135))) - exp(ALGEBRAIC(:,219)./( CONSTANTS(:,134).*CONSTANTS(:,135))));
    ALGEBRAIC(:,39) = piecewise({VOI>CONSTANTS(:,128)&VOI<CONSTANTS(:,129), CONSTANTS(:,130) }, CONSTANTS(:,131));
    ALGEBRAIC(:,225) =  CONSTANTS(:,132).*ALGEBRAIC(:,224).*CONSTANTS(:,104);
    ALGEBRAIC(:,216) =  ALGEBRAIC(:,205).*(CONSTANTS(:,163) - CONSTANTS(:,159))+ ALGEBRAIC(:,206).*(CONSTANTS(:,164) - CONSTANTS(:,160))+ ALGEBRAIC(:,208).*(CONSTANTS(:,162) - CONSTANTS(:,158))+ ALGEBRAIC(:,210).*(CONSTANTS(:,163) - CONSTANTS(:,159))+ ALGEBRAIC(:,212).*(CONSTANTS(:,164) - CONSTANTS(:,160))+ ALGEBRAIC(:,202).*(CONSTANTS(:,162) - CONSTANTS(:,158))+ ALGEBRAIC(:,183).*(CONSTANTS(:,161) - CONSTANTS(:,157))+ ALGEBRAIC(:,179).*(CONSTANTS(:,161) - CONSTANTS(:,157))+ ALGEBRAIC(:,175).*(CONSTANTS(:,161) - CONSTANTS(:,157))+ ALGEBRAIC(:,200).*(CONSTANTS(:,164) - CONSTANTS(:,160))+ ALGEBRAIC(:,198).*(CONSTANTS(:,163) - CONSTANTS(:,159))+ ALGEBRAIC(:,196).*(CONSTANTS(:,162) - CONSTANTS(:,158))+ ALGEBRAIC(:,194).*(CONSTANTS(:,164) - CONSTANTS(:,160))+ ALGEBRAIC(:,190).*(CONSTANTS(:,163) - CONSTANTS(:,159))+ ALGEBRAIC(:,187).*(CONSTANTS(:,162) - CONSTANTS(:,158))+ ALGEBRAIC(:,172).*(CONSTANTS(:,161) - CONSTANTS(:,157))+ ALGEBRAIC(:,169).*(CONSTANTS(:,161) - CONSTANTS(:,157))+ ALGEBRAIC(:,164).*(CONSTANTS(:,161) - CONSTANTS(:,157));
    ALGEBRAIC(:,217) =  CONSTANTS(:,104).*((ALGEBRAIC(:,216) -  CONSTANTS(:,132).*(ALGEBRAIC(:,127)+ALGEBRAIC(:,143))) -  CONSTANTS(:,133).*(ALGEBRAIC(:,129)+ALGEBRAIC(:,146)));
    ALGEBRAIC(:,227) = ( - ALGEBRAIC(:,225) - ALGEBRAIC(:,217))+ALGEBRAIC(:,39);
    ALGEBRAIC(:,220) =  CONSTANTS(:,134).*CONSTANTS(:,135).*log( CONSTANTS(:,84).*STATES(:,45));
    ALGEBRAIC(:,226) =  CONSTANTS(:,40).*(exp(ALGEBRAIC(:,223)./( CONSTANTS(:,134).*CONSTANTS(:,135))) - exp((ALGEBRAIC(:,220)+ CONSTANTS(:,166).*ALGEBRAIC(:,219))./( CONSTANTS(:,134).*CONSTANTS(:,135))));
    ALGEBRAIC(:,221) =  CONSTANTS(:,134).*CONSTANTS(:,135).*log( CONSTANTS(:,85).*STATES(:,46));
    ALGEBRAIC(:,228) =  CONSTANTS(:,41).*(exp((ALGEBRAIC(:,220)+ CONSTANTS(:,165).*ALGEBRAIC(:,219))./( CONSTANTS(:,134).*CONSTANTS(:,135))) - exp(ALGEBRAIC(:,221)./( CONSTANTS(:,134).*CONSTANTS(:,135))));
    ALGEBRAIC(:,222) =  CONSTANTS(:,134).*CONSTANTS(:,135).*log( CONSTANTS(:,86).*STATES(:,47));
    ALGEBRAIC(:,229) =  CONSTANTS(:,42).*(exp((ALGEBRAIC(:,221)+ CONSTANTS(:,166).*ALGEBRAIC(:,219))./( CONSTANTS(:,134).*CONSTANTS(:,135))) - exp(ALGEBRAIC(:,222)./( CONSTANTS(:,134).*CONSTANTS(:,135))));
    ALGEBRAIC(:,230) =  CONSTANTS(:,43).*(exp(ALGEBRAIC(:,222)./( CONSTANTS(:,134).*CONSTANTS(:,135))) - exp((ALGEBRAIC(:,223)+ CONSTANTS(:,165).*ALGEBRAIC(:,219))./( CONSTANTS(:,134).*CONSTANTS(:,135))));
    ALGEBRAIC(:,231) = (( CONSTANTS(:,166).*ALGEBRAIC(:,226) -  CONSTANTS(:,165).*ALGEBRAIC(:,228)) -  CONSTANTS(:,166).*ALGEBRAIC(:,229))+ CONSTANTS(:,165).*ALGEBRAIC(:,230);
    ALGEBRAIC(:,5) = STATES(:,25)./CONSTANTS(:,170);
    ALGEBRAIC(:,6) = STATES(:,26)./CONSTANTS(:,175);
    ALGEBRAIC(:,7) = STATES(:,24)./CONSTANTS(:,179);
    ALGEBRAIC(:,8) = STATES(:,28)./CONSTANTS(:,170);
    ALGEBRAIC(:,9) = STATES(:,27)./CONSTANTS(:,170);
    ALGEBRAIC(:,10) = STATES(:,29)./CONSTANTS(:,170);
    ALGEBRAIC(:,21) = ALGEBRAIC(:,11)+ALGEBRAIC(:,15);
    ALGEBRAIC(:,28) = ALGEBRAIC(:,24);
    ALGEBRAIC(:,32) = ALGEBRAIC(:,1)+ALGEBRAIC(:,15)+ALGEBRAIC(:,26)+ALGEBRAIC(:,23);
    ALGEBRAIC(:,33) = ALGEBRAIC(:,27);
    ALGEBRAIC(:,37) =  CONSTANTS(:,156).*(STATES(:,33)+STATES(:,34)+STATES(:,35)+STATES(:,36)+STATES(:,37)+STATES(:,38));
    ALGEBRAIC(:,41) =  CONSTANTS(:,166).*STATES(:,48)+ CONSTANTS(:,165).*STATES(:,46)+ (CONSTANTS(:,165)+CONSTANTS(:,166)).*STATES(:,47);
    ALGEBRAIC(:,42) = ALGEBRAIC(:,30)+ALGEBRAIC(:,35);
    ALGEBRAIC(:,45) = ALGEBRAIC(:,39)./( CONSTANTS(:,132).*CONSTANTS(:,104));
    ALGEBRAIC(:,48) =  CONSTANTS(:,167).*STATES(:,52)+ CONSTANTS(:,167).*STATES(:,53)+ CONSTANTS(:,168).*STATES(:,55);
    ALGEBRAIC(:,53) = ALGEBRAIC(:,14)+ALGEBRAIC(:,18)+ALGEBRAIC(:,31)+ALGEBRAIC(:,20)+ALGEBRAIC(:,37)+ALGEBRAIC(:,48)+ALGEBRAIC(:,41);
end

% Functions required for solving differential algebraic equation
function [CONSTANTS, STATES, ALGEBRAIC] = rootfind_0(VOI, CONSTANTS_IN, STATES_IN, ALGEBRAIC_IN)
    ALGEBRAIC = ALGEBRAIC_IN;
    CONSTANTS = CONSTANTS_IN;
    STATES = STATES_IN;
    global initialGuess_0;
    if (length(initialGuess_0) ~= 4), initialGuess_0 = [0.1,0.1,0.1,0.1];, end
    options = optimset('Display', 'off', 'TolX', 1E-6);
    if length(VOI) == 1
        residualfn = @(algebraicCandidate)residualSN_0(algebraicCandidate, ALGEBRAIC, VOI, CONSTANTS, STATES);
        soln = fsolve(residualfn, initialGuess_0, options);
        initialGuess_0 = soln;
        ALGEBRAIC(:,74) = soln(1);
        ALGEBRAIC(:,75) = soln(2);
        ALGEBRAIC(:,76) = soln(3);
        ALGEBRAIC(:,77) = soln(4);
    else
        SET_ALGEBRAIC(:,74) = logical(1);
        SET_ALGEBRAIC(:,75) = logical(1);
        SET_ALGEBRAIC(:,76) = logical(1);
        SET_ALGEBRAIC(:,77) = logical(1);
        for i=1:length(VOI)
            residualfn = @(algebraicCandidate)residualSN_0(algebraicCandidate, ALGEBRAIC(i,:), VOI(i), CONSTANTS, STATES(i,:));
            soln = fsolve(residualfn, initialGuess_0, options);
            initialGuess_0 = soln;
            TEMP_ALGEBRAIC(:,74) = soln(1);
            TEMP_ALGEBRAIC(:,75) = soln(2);
            TEMP_ALGEBRAIC(:,76) = soln(3);
            TEMP_ALGEBRAIC(:,77) = soln(4);
            ALGEBRAIC(i,SET_ALGEBRAIC) = TEMP_ALGEBRAIC(SET_ALGEBRAIC);
        end
    end
end

function resid = residualSN_0(algebraicCandidate, ALGEBRAIC, VOI, CONSTANTS, STATES)
    ALGEBRAIC(:,74) = algebraicCandidate(1);
    ALGEBRAIC(:,75) = algebraicCandidate(2);
    ALGEBRAIC(:,76) = algebraicCandidate(3);
    ALGEBRAIC(:,77) = algebraicCandidate(4);
    resid(1) = ALGEBRAIC(:,74) - piecewise({ALGEBRAIC(:,75)>0.000000, CONSTANTS(:,152) }, CONSTANTS(:,153));
    resid(2) = ALGEBRAIC(:,76) -  (CONSTANTS(:,154)./ALGEBRAIC(:,74)).*STATES(:,32).*CONSTANTS(:,150);
    resid(3) = ALGEBRAIC(:,77) -  (CONSTANTS(:,154)./ALGEBRAIC(:,74)).*(STATES(:,9) - CONSTANTS(:,141)).*CONSTANTS(:,150);
    resid(4) = ALGEBRAIC(:,75) - ( - ALGEBRAIC(:,76)+ALGEBRAIC(:,77));
end

% Compute result of a piecewise function
function x = piecewise(cases, default)
    set = [0];
    for i = 1:2:length(cases)
        if (length(cases{i+1}) == 1)
            x(cases{i} & ~set,:) = cases{i+1};
        else
            x(cases{i} & ~set,:) = cases{i+1}(cases{i} & ~set);
        end
        set = set | cases{i};
        if(set), break, end
    end
    if (length(default) == 1)
        x(~set,:) = default;
    else
        x(~set,:) = default(~set);
    end
end

% Pad out or shorten strings to a set length
function strout = strpad(strin)
    req_length = 160;
    insize = size(strin,2);
    if insize > req_length
        strout = strin(1:req_length);
    else
        strout = [strin, blanks(req_length - insize)];
    end
end

